<?php

if ( ! function_exists( 'solene_core_map_masonry_gallery_meta' ) ) {
	function solene_core_map_masonry_gallery_meta() {
		
		$masonry_gallery_meta_box = solene_elated_create_meta_box(
			array(
				'scope' => array( 'masonry-gallery' ),
				'title' => esc_html__( 'Masonry Gallery General', 'solene-core' ),
				'name'  => 'masonry_gallery_meta'
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_masonry_gallery_item_type',
				'type'          => 'select',
				'default_value' => 'standard',
				'label'         => esc_html__( 'Type', 'solene-core' ),
				'parent'        => $masonry_gallery_meta_box,
				'options'       => array(
					'standard'    => esc_html__( 'Standard', 'solene-core' ),
					'with-button' => esc_html__( 'With Button', 'solene-core' ),
					'textual'     => esc_html__( 'Textual', 'solene-core' ),
					'simple'      => esc_html__( 'Simple', 'solene-core' )
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_masonry_gallery_item_size',
				'type'          => 'select',
				'default_value' => 'small',
				'label'         => esc_html__( 'Size', 'solene-core' ),
				'parent'        => $masonry_gallery_meta_box,
				'options'       => array(
					'small'              => esc_html__( 'Small', 'solene-core' ),
					'large-width'        => esc_html__( 'Large Width', 'solene-core' ),
					'large-height'       => esc_html__( 'Large Height', 'solene-core' ),
					'large-width-height' => esc_html__( 'Large Width/Height', 'solene-core' )
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_masonry_gallery_item_title_tag',
				'type'          => 'select',
				'default_value' => 'h2',
				'label'         => esc_html__( 'Title Tag', 'solene-core' ),
				'parent'        => $masonry_gallery_meta_box,
				'options'       => solene_elated_get_title_tag( true, array( 'span' => esc_html__( 'Custom Heading' ) ) ),
				'dependency'    => array(
					'hide' => array(
						'eltdf_masonry_gallery_item_type' => array( 'simple', 'textual' )
					)
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'       => 'eltdf_masonry_gallery_item_text',
				'type'       => 'text',
				'label'      => esc_html__( 'Text', 'solene-core' ),
				'parent'     => $masonry_gallery_meta_box,
				'dependency' => array(
					'show' => array(
						'eltdf_masonry_gallery_item_type' => array( 'standard', 'textual' )
					)
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_masonry_gallery_item_text_tag',
				'type'          => 'select',
				'default_value' => 'p',
				'label'         => esc_html__( 'Text Tag', 'solene-core' ),
				'parent'        => $masonry_gallery_meta_box,
				'options'       => solene_elated_get_title_tag( true, array( 'p' => 'p', 'span' => esc_html__( 'Custom Heading' ) ) ),
				'dependency'    => array(
					'show' => array(
						'eltdf_masonry_gallery_item_type' => array( 'standard', 'textual' )
					)
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'       => 'eltdf_masonry_gallery_custom_icon',
				'type'       => 'image',
				'label'      => esc_html__( 'Custom Icon', 'solene-core' ),
				'parent'     => $masonry_gallery_meta_box,
				'dependency' => array(
					'show' => array(
						'eltdf_masonry_gallery_item_type' => array( 'standard' )
					)
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'       => 'eltdf_masonry_gallery_button_label',
				'type'       => 'text',
				'label'      => esc_html__( 'Button Label', 'solene-core' ),
				'parent'     => $masonry_gallery_meta_box,
				'dependency' => array(
					'show' => array(
						'eltdf_masonry_gallery_item_type' => array( 'with-button' )
					)
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'   => 'eltdf_masonry_gallery_item_link',
				'type'   => 'text',
				'label'  => esc_html__( 'Link', 'solene-core' ),
				'parent' => $masonry_gallery_meta_box
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_masonry_gallery_item_link_target',
				'type'          => 'select',
				'default_value' => '_self',
				'label'         => esc_html__( 'Link Target', 'solene-core' ),
				'options'       => solene_elated_get_link_target_array(),
				'parent'        => $masonry_gallery_meta_box
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_masonry_gallery_content_skin',
				'type'          => 'select',
				'default_value' => '',
				'label'         => esc_html__( 'Content Skin', 'solene-core' ),
				'options'       => array(
					'default' => esc_html__( 'Default', 'solene-core' ),
					'light'   => esc_html__( 'Light', 'solene-core' )
				),
				'parent'        => $masonry_gallery_meta_box,
				'dependency'    => array(
					'hide' => array(
						'eltdf_masonry_gallery_item_type' => array( 'simple' )
					)
				)
			)
		);
	}
	
	add_action( 'solene_elated_action_meta_boxes_map', 'solene_core_map_masonry_gallery_meta', 45 );
}