<?php
class SoleneCoreElementorMasonryGallery extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_masonry_gallery'; 
	}

	public function get_title() {
		return esc_html__( 'Masonry Gallery', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-masonry-gallery-list';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'number_of_items',
			[
				'label'     => esc_html__( 'Number of Items', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'space_between_items',
			[
				'label'     => esc_html__( 'Space Between Items', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'huge' => esc_html__( 'Huge (54)', 'solene-core'), 
					'large' => esc_html__( 'Large (25)', 'solene-core'), 
					'medium' => esc_html__( 'Medium (20)', 'solene-core'), 
					'normal' => esc_html__( 'Normal (15)', 'solene-core'), 
					'small' => esc_html__( 'Small (10)', 'solene-core'), 
					'tiny' => esc_html__( 'Tiny (5)', 'solene-core'), 
					'no' => esc_html__( 'No (0)', 'solene-core')
				),
				'default' => 'normal'
			]
		);

		$this->add_control(
			'category',
			[
				'label'     => esc_html__( 'Category', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter one category slug (leave empty for showing all categories)', 'solene-core' )
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'     => esc_html__( 'Order By', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'date' => esc_html__( 'Date', 'solene-core'), 
					'ID' => esc_html__( 'ID', 'solene-core'), 
					'menu_order' => esc_html__( 'Menu Order', 'solene-core'), 
					'name' => esc_html__( 'Post Name', 'solene-core'), 
					'rand' => esc_html__( 'Random', 'solene-core'), 
					'title' => esc_html__( 'Title', 'solene-core')
				),
				'default' => 'date'
			]
		);

		$this->add_control(
			'order',
			[
				'label'     => esc_html__( 'Order', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'ASC' => esc_html__( 'ASC', 'solene-core'), 
					'DESC' => esc_html__( 'DESC', 'solene-core')
				),
				'default' => 'ASC'
			]
		);


		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();

		$query_array                         = $this->getQueryArray( $params );
		$query_results                       = new \WP_Query( $query_array );
		$additional_params['query_results']  = $query_results;
		$additional_params['holder_classes'] = $this->getHolderClasses( $params );
		
		$params['this_object'] = $this;

        echo solene_core_get_cpt_shortcode_module_template_part( 'masonry-gallery', 'masonry-gallery-list', 'masonry-gallery-holder', '', $params, $additional_params );
	}

	private function getQueryArray( $params ) {
		$query_array = array(
			'post_status'    => 'publish',
			'post_type'      => 'masonry-gallery',
			'posts_per_page' => $params['number_of_items'],
			'orderby'        => $params['orderby'],
			'order'          => $params['order']
		);
		
		if ( ! empty( $params['category'] ) ) {
			$query_array['masonry-gallery-category'] = $params['category'];
		}
		
		return $query_array;
	}

	private function getHolderClasses( $params ) {
		$classes = array();
		
		$classes[] = ! empty( $params['space_between_items'] ) ? 'eltdf-' . $params['space_between_items'] . '-space' : '';
		
		return implode( ' ', $classes );
	}

	public function getItemClasses() {
		$classes = array( 'eltdf-mg-item' );
		
		$itemID       = get_the_ID();
		$type         = get_post_meta( $itemID, 'eltdf_masonry_gallery_item_type', true );
		$image_size   = get_post_meta( $itemID, 'eltdf_masonry_gallery_item_size', true );
		$content_skin = get_post_meta( $itemID, 'eltdf_masonry_gallery_content_skin', true );
		
		if ( ! empty( $type ) ) {
			$classes[] = 'eltdf-mg-' . $type;
		}
		
		if ( ! empty( $image_size ) ) {
			$classes[] = 'eltdf-masonry-size-' . $image_size;
		}
		
		if ( ! empty( $content_skin ) ) {
			$classes[] = 'eltdf-mg-skin-' . $content_skin;
		}
		
		return implode( ' ', $classes );
	}

	public function getItemImageStyles( $item_id ) {
		$styles = array();
		$image_url = wp_get_attachment_url( get_post_thumbnail_id( $item_id ) );
		
		if ( ! empty( $image_url ) ) {
			$styles[] = 'background-image: url(' . esc_url( $image_url ) . ')';
		}

		return implode( ';', $styles );
	}

	public function getItemCustomIcon( $item_id ) {
		$custom_icon = get_post_meta( $item_id, 'eltdf_masonry_gallery_custom_icon', true );
		$image_meta  = array();
		
		if ( ! empty( $custom_icon ) ) {
			$image_id = solene_elated_get_attachment_id_from_url( $custom_icon );
			
			$image_meta['url'] = $custom_icon;
			$image_meta['alt'] = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
		}
		
		return $image_meta;
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorMasonryGallery() );