<?php

if ( ! function_exists( 'solene_core_map_portfolio_settings_meta' ) ) {
	function solene_core_map_portfolio_settings_meta() {
		$meta_box = solene_elated_create_meta_box( array(
			'scope' => 'portfolio-item',
			'title' => esc_html__( 'Portfolio Settings', 'solene-core' ),
			'name'  => 'portfolio_settings_meta_box'
		) );
		
		solene_elated_create_meta_box_field( array(
			'name'        => 'eltdf_portfolio_single_template_meta',
			'type'        => 'select',
			'label'       => esc_html__( 'Portfolio Type', 'solene-core' ),
			'description' => esc_html__( 'Choose a default type for Single Project pages', 'solene-core' ),
			'parent'      => $meta_box,
			'options'     => array(
				''                  => esc_html__( 'Default', 'solene-core' ),
				'huge-images'       => esc_html__( 'Portfolio Full Width Images', 'solene-core' ),
				'images'            => esc_html__( 'Portfolio Images', 'solene-core' ),
				'small-images'      => esc_html__( 'Portfolio Small Images', 'solene-core' ),
				'slider'            => esc_html__( 'Portfolio Slider', 'solene-core' ),
				'small-slider'      => esc_html__( 'Portfolio Small Slider', 'solene-core' ),
				'gallery'           => esc_html__( 'Portfolio Gallery', 'solene-core' ),
				'small-gallery'     => esc_html__( 'Portfolio Small Gallery', 'solene-core' ),
				'masonry'           => esc_html__( 'Portfolio Masonry', 'solene-core' ),
				'small-masonry'     => esc_html__( 'Portfolio Small Masonry', 'solene-core' ),
				'custom'            => esc_html__( 'Portfolio Custom', 'solene-core' ),
				'full-width-custom' => esc_html__( 'Portfolio Full Width Custom', 'solene-core' )
			)
		) );
		
		/***************** Gallery Layout *****************/
		
		$gallery_type_meta_container = solene_elated_add_admin_container(
			array(
				'parent'          => $meta_box,
				'name'            => 'eltdf_gallery_type_meta_container',
				'dependency' => array(
					'show' => array(
						'eltdf_portfolio_single_template_meta'  => array(
							'gallery',
							'small-gallery'
						)
					)
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_portfolio_single_gallery_columns_number_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Number of Columns', 'solene-core' ),
				'default_value' => '',
				'description'   => esc_html__( 'Set number of columns for portfolio gallery type', 'solene-core' ),
				'parent'        => $gallery_type_meta_container,
				'options'       => solene_elated_get_number_of_columns_array( true, array( 'one', 'five', 'six' ) )
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_portfolio_single_gallery_space_between_items_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Space Between Items', 'solene-core' ),
				'description'   => esc_html__( 'Set space size between columns for portfolio gallery type', 'solene-core' ),
				'default_value' => '',
				'options'       => solene_elated_get_space_between_items_array( true ),
				'parent'        => $gallery_type_meta_container
			)
		);
		
		/***************** Gallery Layout *****************/
		
		/***************** Masonry Layout *****************/
		
		$masonry_type_meta_container = solene_elated_add_admin_container(
			array(
				'parent'          => $meta_box,
				'name'            => 'eltdf_masonry_type_meta_container',
				'dependency' => array(
					'show' => array(
						'eltdf_portfolio_single_template_meta'  => array(
							'masonry',
							'small-masonry'
						)
					)
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_portfolio_single_masonry_columns_number_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Number of Columns', 'solene-core' ),
				'default_value' => '',
				'description'   => esc_html__( 'Set number of columns for portfolio masonry type', 'solene-core' ),
				'parent'        => $masonry_type_meta_container,
				'options'       => solene_elated_get_number_of_columns_array( true, array( 'one', 'five', 'six' ) )
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_portfolio_single_masonry_space_between_items_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Space Between Items', 'solene-core' ),
				'description'   => esc_html__( 'Set space size between columns for portfolio masonry type', 'solene-core' ),
				'default_value' => '',
				'options'       => solene_elated_get_space_between_items_array( true ),
				'parent'        => $masonry_type_meta_container
			)
		);
		
		/***************** Masonry Layout *****************/
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_show_title_area_portfolio_single_meta',
				'type'          => 'select',
				'default_value' => '',
				'label'         => esc_html__( 'Show Title Area', 'solene-core' ),
				'description'   => esc_html__( 'Enabling this option will show title area on your single portfolio page', 'solene-core' ),
				'parent'        => $meta_box,
				'options'       => solene_elated_get_yes_no_select_array()
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'        => 'portfolio_info_top_padding',
				'type'        => 'text',
				'label'       => esc_html__( 'Portfolio Info Top Padding', 'solene-core' ),
				'description' => esc_html__( 'Set top padding for portfolio info elements holder. This option works only for Portfolio Images, Slider, Gallery and Masonry portfolio types', 'solene-core' ),
				'parent'      => $meta_box,
				'args'        => array(
					'col_width' => 3,
					'suffix'    => 'px'
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'        => 'portfolio_external_link',
				'type'        => 'text',
				'label'       => esc_html__( 'Portfolio External Link', 'solene-core' ),
				'description' => esc_html__( 'Enter URL to link from Portfolio List page', 'solene-core' ),
				'parent'      => $meta_box,
				'args'        => array(
					'col_width' => 3
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'        => 'eltdf_portfolio_featured_image_meta',
				'type'        => 'image',
				'label'       => esc_html__( 'Featured Hover Image', 'solene-core' ),
				'description' => esc_html__( 'Choose an hover image for Featured Image on Horizontal Scrolling Portfolio List shortcode', 'solene-core' ),
				'parent'      => $meta_box
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_portfolio_masonry_padding_meta',
				'type'          => 'text',
				'label'         => esc_html__( 'Padding for Masonry List - Image Original Proportion (%)', 'solene-core' ),
				'description'   => esc_html__( 'Choose item padding when it appears in Masonry type Portfolio lists where image proportion is original', 'solene-core' ),
				'default_value' => '',
				'parent'        => $meta_box,
				'args'        => array(
					'col_width' => 3
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_portfolio_masonry_fixed_dimensions_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Dimensions for Masonry - Image Fixed Proportion', 'solene-core' ),
				'description'   => esc_html__( 'Choose image layout when it appears in Masonry type portfolio lists where image proportion is fixed', 'solene-core' ),
				'default_value' => '',
				'parent'        => $meta_box,
				'options'       => array(
					''                   => esc_html__( 'Default', 'solene-core' ),
					'small'              => esc_html__( 'Small', 'solene-core' ),
					'large-width'        => esc_html__( 'Large Width', 'solene-core' ),
					'large-height'       => esc_html__( 'Large Height', 'solene-core' ),
					'large-width-height' => esc_html__( 'Large Width/Height', 'solene-core' )
				)
			)
		);
		
		solene_elated_create_meta_box_field(
			array(
				'name'          => 'eltdf_portfolio_masonry_original_dimensions_meta',
				'type'          => 'select',
				'label'         => esc_html__( 'Dimensions for Masonry - Image Original Proportion', 'solene-core' ),
				'description'   => esc_html__( 'Choose image layout when it appears in Masonry type portfolio lists where image proportion is original', 'solene-core' ),
				'default_value' => '',
				'parent'        => $meta_box,
				'options'       => array(
					''            => esc_html__( 'Default', 'solene-core' ),
					'large-width' => esc_html__( 'Large Width', 'solene-core' )
				)
			)
		);
		
		$all_pages = array();
		$pages     = get_pages();
		foreach ( $pages as $page ) {
			$all_pages[ $page->ID ] = $page->post_title;
		}
		
		solene_elated_create_meta_box_field(
			array(
				'name'        => 'portfolio_single_back_to_link',
				'type'        => 'select',
				'label'       => esc_html__( '"Back To" Link', 'solene-core' ),
				'description' => esc_html__( 'Choose "Back To" page to link from portfolio Single Project page', 'solene-core' ),
				'parent'      => $meta_box,
				'options'     => $all_pages,
				'args'        => array(
					'select2' => true
				)
			)
		);
	}
	
	add_action( 'solene_elated_action_meta_boxes_map', 'solene_core_map_portfolio_settings_meta', 41 );
}