<?php

if ( ! function_exists( 'solene_elated_portfolio_options_map' ) ) {
	function solene_elated_portfolio_options_map() {
		
		solene_elated_add_admin_page(
			array(
				'slug'  => '_portfolio',
				'title' => esc_html__( 'Portfolio', 'solene-core' ),
				'icon'  => 'fa fa-camera-retro'
			)
		);
		
		$panel_archive = solene_elated_add_admin_panel(
			array(
				'title' => esc_html__( 'Portfolio Archive', 'solene-core' ),
				'name'  => 'panel_portfolio_archive',
				'page'  => '_portfolio'
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'        => 'portfolio_archive_number_of_items',
				'type'        => 'text',
				'label'       => esc_html__( 'Number of Items', 'solene-core' ),
				'description' => esc_html__( 'Set number of items for your portfolio list on archive pages. Default value is 12', 'solene-core' ),
				'parent'      => $panel_archive,
				'args'        => array(
					'col_width' => 3
				)
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_archive_number_of_columns',
				'type'          => 'select',
				'label'         => esc_html__( 'Number of Columns', 'solene-core' ),
				'default_value' => 'three',
				'description'   => esc_html__( 'Set number of columns for your portfolio list on archive pages. Default value is Three columns', 'solene-core' ),
				'parent'        => $panel_archive,
				'options'       => solene_elated_get_number_of_columns_array( false, array( 'one', 'six' ) )
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_archive_space_between_items',
				'type'          => 'select',
				'label'         => esc_html__( 'Space Between Items', 'solene-core' ),
				'description'   => esc_html__( 'Set space size between portfolio items for your portfolio list on archive pages. Default value is normal', 'solene-core' ),
				'default_value' => 'normal',
				'options'       => solene_elated_get_space_between_items_array(),
				'parent'        => $panel_archive
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_archive_image_size',
				'type'          => 'select',
				'label'         => esc_html__( 'Image Proportions', 'solene-core' ),
				'default_value' => 'landscape',
				'description'   => esc_html__( 'Set image proportions for your portfolio list on archive pages. Default value is landscape', 'solene-core' ),
				'parent'        => $panel_archive,
				'options'       => array(
					'full'      => esc_html__( 'Original', 'solene-core' ),
					'landscape' => esc_html__( 'Landscape', 'solene-core' ),
					'portrait'  => esc_html__( 'Portrait', 'solene-core' ),
					'square'    => esc_html__( 'Square', 'solene-core' )
				)
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_archive_item_layout',
				'type'          => 'select',
				'label'         => esc_html__( 'Item Style', 'solene-core' ),
				'default_value' => 'standard',
				'description'   => esc_html__( 'Set item style for your portfolio list on archive pages. Default value is Standard', 'solene-core' ),
				'parent'        => $panel_archive,
				'options'       => array(
					'standard'        => esc_html__( 'Standard', 'solene-core' ),
					'gallery-overlay' => esc_html__( 'Gallery - Overlay', 'solene-core' )
				)
			)
		);
		
		$panel = solene_elated_add_admin_panel(
			array(
				'title' => esc_html__( 'Portfolio Single', 'solene-core' ),
				'name'  => 'panel_portfolio_single',
				'page'  => '_portfolio'
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_template',
				'type'          => 'select',
				'label'         => esc_html__( 'Portfolio Type', 'solene-core' ),
				'default_value' => 'small-images',
				'description'   => esc_html__( 'Choose a default type for Single Project pages', 'solene-core' ),
				'parent'        => $panel,
				'options'       => array(
					'huge-images'       => esc_html__( 'Portfolio Full Width Images', 'solene-core' ),
					'images'            => esc_html__( 'Portfolio Images', 'solene-core' ),
					'small-images'      => esc_html__( 'Portfolio Small Images', 'solene-core' ),
					'slider'            => esc_html__( 'Portfolio Slider', 'solene-core' ),
					'small-slider'      => esc_html__( 'Portfolio Small Slider', 'solene-core' ),
					'gallery'           => esc_html__( 'Portfolio Gallery', 'solene-core' ),
					'small-gallery'     => esc_html__( 'Portfolio Small Gallery', 'solene-core' ),
					'masonry'           => esc_html__( 'Portfolio Masonry', 'solene-core' ),
					'small-masonry'     => esc_html__( 'Portfolio Small Masonry', 'solene-core' ),
					'custom'            => esc_html__( 'Portfolio Custom', 'solene-core' ),
					'full-width-custom' => esc_html__( 'Portfolio Full Width Custom', 'solene-core' )
				)
			)
		);
		
		/***************** Gallery Layout *****************/
		
		$portfolio_gallery_container = solene_elated_add_admin_container(
			array(
				'parent'          => $panel,
				'name'            => 'portfolio_gallery_container',
				'dependency' => array(
					'show' => array(
						'portfolio_single_template'  => array(
							'gallery',
							'small-gallery'
						)
					)
				)
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_gallery_columns_number',
				'type'          => 'select',
				'label'         => esc_html__( 'Number of Columns', 'solene-core' ),
				'default_value' => 'three',
				'description'   => esc_html__( 'Set number of columns for portfolio gallery type', 'solene-core' ),
				'parent'        => $portfolio_gallery_container,
				'options'       => solene_elated_get_number_of_columns_array( false, array( 'one', 'five', 'six' ) )
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_gallery_space_between_items',
				'type'          => 'select',
				'label'         => esc_html__( 'Space Between Items', 'solene-core' ),
				'description'   => esc_html__( 'Set space size between columns for portfolio gallery type', 'solene-core' ),
				'default_value' => 'normal',
				'options'       => solene_elated_get_space_between_items_array(),
				'parent'        => $portfolio_gallery_container
			)
		);
		
		/***************** Gallery Layout *****************/
		
		/***************** Masonry Layout *****************/
		
		$portfolio_masonry_container = solene_elated_add_admin_container(
			array(
				'parent'          => $panel,
				'name'            => 'portfolio_masonry_container',
				'dependency' => array(
					'show' => array(
						'portfolio_single_template'  => array(
							'masonry',
							'small-masonry'
						)
					)
				)
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_masonry_columns_number',
				'type'          => 'select',
				'label'         => esc_html__( 'Number of Columns', 'solene-core' ),
				'default_value' => 'three',
				'description'   => esc_html__( 'Set number of columns for portfolio masonry type', 'solene-core' ),
				'parent'        => $portfolio_masonry_container,
				'options'       => solene_elated_get_number_of_columns_array( false, array( 'one', 'five', 'six' ) )
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_masonry_space_between_items',
				'type'          => 'select',
				'label'         => esc_html__( 'Space Between Items', 'solene-core' ),
				'description'   => esc_html__( 'Set space size between columns for portfolio masonry type', 'solene-core' ),
				'default_value' => 'normal',
				'options'       => solene_elated_get_space_between_items_array(),
				'parent'        => $portfolio_masonry_container
			)
		);
		
		/***************** Masonry Layout *****************/
		
		solene_elated_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'show_title_area_portfolio_single',
				'default_value' => '',
				'label'         => esc_html__( 'Show Title Area', 'solene-core' ),
				'description'   => esc_html__( 'Enabling this option will show title area on single projects', 'solene-core' ),
				'parent'        => $panel,
				'options'       => array(
					''    => esc_html__( 'Default', 'solene-core' ),
					'yes' => esc_html__( 'Yes', 'solene-core' ),
					'no'  => esc_html__( 'No', 'solene-core' )
				),
				'args'          => array(
					'col_width' => 3
				)
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_lightbox_images',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Enable Lightbox for Images', 'solene-core' ),
				'description'   => esc_html__( 'Enabling this option will turn on lightbox functionality for projects with images', 'solene-core' ),
				'parent'        => $panel,
				'default_value' => 'yes'
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_lightbox_videos',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Enable Lightbox for Videos', 'solene-core' ),
				'description'   => esc_html__( 'Enabling this option will turn on lightbox functionality for YouTube/Vimeo projects', 'solene-core' ),
				'parent'        => $panel,
				'default_value' => 'no'
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_enable_categories',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Enable Categories', 'solene-core' ),
				'description'   => esc_html__( 'Enabling this option will enable category meta description on single projects', 'solene-core' ),
				'parent'        => $panel,
				'default_value' => 'yes'
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_hide_date',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Enable Date', 'solene-core' ),
				'description'   => esc_html__( 'Enabling this option will enable date meta on single projects', 'solene-core' ),
				'parent'        => $panel,
				'default_value' => 'yes'
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_sticky_sidebar',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Enable Sticky Side Text', 'solene-core' ),
				'description'   => esc_html__( 'Enabling this option will make side text sticky on Single Project pages. This option works only for Full Width Images, Small Images, Small Gallery and Small Masonry portfolio types', 'solene-core' ),
				'parent'        => $panel,
				'default_value' => 'yes'
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_comments',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Show Comments', 'solene-core' ),
				'description'   => esc_html__( 'Enabling this option will show comments on your page', 'solene-core' ),
				'parent'        => $panel,
				'default_value' => 'no'
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_hide_pagination',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Hide Pagination', 'solene-core' ),
				'description'   => esc_html__( 'Enabling this option will turn off portfolio pagination functionality', 'solene-core' ),
				'parent'        => $panel,
				'default_value' => 'no'
			)
		);
		
		$container_navigate_category = solene_elated_add_admin_container(
			array(
				'name'            => 'navigate_same_category_container',
				'parent'          => $panel,
				'dependency' => array(
					'hide' => array(
						'portfolio_single_hide_pagination'  => array(
							'yes'
						)
					)
				)
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'          => 'portfolio_single_nav_same_category',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Enable Pagination Through Same Category', 'solene-core' ),
				'description'   => esc_html__( 'Enabling this option will make portfolio pagination sort through current category', 'solene-core' ),
				'parent'        => $container_navigate_category,
				'default_value' => 'no'
			)
		);
		
		solene_elated_add_admin_field(
			array(
				'name'        => 'portfolio_single_slug',
				'type'        => 'text',
				'label'       => esc_html__( 'Portfolio Single Slug', 'solene-core' ),
				'description' => esc_html__( 'Enter if you wish to use a different Single Project slug (Note: After entering slug, navigate to Settings -> Permalinks and click "Save" in order for changes to take effect)', 'solene-core' ),
				'parent'      => $panel,
				'args'        => array(
					'col_width' => 3
				)
			)
		);
	}
	
	add_action( 'solene_elated_action_options_map', 'solene_elated_portfolio_options_map', solene_elated_set_options_map_position( 'portfolio' ) );
}