(function ($) {
	'use strict';
	
	var horizontalScrollingPortfolioList = {};
	eltdf.modules.horizontalScrollingPortfolioList = horizontalScrollingPortfolioList;
	
	horizontalScrollingPortfolioList.eltdfOnDocumentReady = eltdfOnDocumentReady;
	
	$(document).ready(eltdfOnDocumentReady);
	$(window).on('load',eltdfOnWindowLoad);

	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function eltdfOnDocumentReady() {
		eltdfHorizontalScrollingPortfolio.init();
		eltdfBlurImage();
		eltdfInitTouchAnimation();
	}

	/*
	 All functions to be called on $(window).on('load',) should be in this function
	 */
	function eltdfOnWindowLoad() {
		eltdfElementorPortfolioHorizontalScrolling();
	}

	/**
	 * Elementor
	 */
	function eltdfElementorPortfolioHorizontalScrolling(){
		$(window).on('elementor/frontend/init', function () {
			elementorFrontend.hooks.addAction( 'frontend/element_ready/eltdf_horizontal_scrolling_portfolio_list.default', function() {
				eltdfHorizontalScrollingPortfolio.init();
				eltdfBlurImage();
				eltdfInitTouchAnimation();
			} );
		});
	}

	var eltdfHorizontalScrollingPortfolio = {
		init: function () {
			this.holder = $('.eltdf-horizontal-scrolling-portfolio-holder');
			
			if (this.holder.length && eltdf.windowWidth > 1024) {
				var currentInstance = this;
				
				currentInstance.holder.each(function () {
					var currentHolder = $(this);
					
					eltdf.body.addClass('eltdf-hspl-active');
					
					eltdfHorizontalScrollingPortfolio.load(currentInstance, currentHolder);
					
					$(window).resize(function(){
						eltdfHorizontalScrollingPortfolio.load(currentInstance, currentHolder);
					});
				});
			}
		},
		load: function (currentInstance, holder) {

			if (eltdf.windowWidth > 768) {
				currentInstance.setMainVariables(currentInstance, holder);
				
				if (eltdf.htmlEl.hasClass('touch')) {
					currentInstance.touchDevicesInit(currentInstance);
				} else {
					currentInstance.devicesInit(currentInstance);
				}
			}
		},
		setMainVariables: function (currentInstance, holder) {
			currentInstance.currentHolder = holder;
			currentInstance.holderOffset = holder.offset().top;
			currentInstance.listInner = holder.find('.eltdf-hspl-inner');
			currentInstance.section = document.querySelector('.eltdf-hspl-inner');
			currentInstance.items = holder.find('.eltdf-hspl-item');
			currentInstance.featureItem = holder.find('.eltdf-hspl-item.eltdf-hspl-featured');
			
			currentInstance.calcHolderHeight(currentInstance);
			
			currentInstance.spaceBetweenItems = parseInt(holder.find('.eltdf-hspl-item:not(.eltdf-hspl-featured)').css('paddingRight'), 10) * 2;
			currentInstance.rowsNumber = 2;
			currentInstance.widthValFeatured = 0;
			
			currentInstance.setFeaturedItemWidth(currentInstance);
			currentInstance.setItemWidth(currentInstance);
		},
		calcHolderHeight: function (currentInstance) {
			var height = eltdf.windowHeight,
				decreaseHeightHeader = currentInstance.currentHolder.data('header-decrease'),
				contentBottomHolder = $('.eltdf-content-bottom'),
				decreaseHeightContentBottom = contentBottomHolder.length ? currentInstance.currentHolder.data('content-bottom-decrease') : 'no';
			
			if (decreaseHeightHeader === 'yes') {
				height = height - currentInstance.holderOffset;
			}
			
			if (decreaseHeightContentBottom === 'yes' && contentBottomHolder.length) {
				height = height - contentBottomHolder.outerHeight();
			}
		
			currentInstance.listInner.css({'height': height});
		},
		setFeaturedItemWidth: function (currentInstance) {
			if (currentInstance.featureItem.length) {
				
				if (eltdf.windowWidth <= 1680) {
					currentInstance.widthValFeatured = Math.round(parseInt(eltdf.windowWidth, 10) * 0.3);
				} else {
					currentInstance.widthValFeatured = Math.round(parseInt(eltdf.windowWidth, 10) * 0.34);
				}
				
				currentInstance.listInner.css('left', currentInstance.widthValFeatured);
				currentInstance.featureItem.width(currentInstance.widthValFeatured);
			}
		},
		setItemWidth: function (currentInstance) {
			var listWidth = 0,
				count = currentInstance.featureItem.length ? currentInstance.items.length - 1 : currentInstance.items.length,
				current = 0,
				sectionHeight = currentInstance.listInner.height();
		
			currentInstance.items.each(function () {
				var item = $(this),
					itemWidth = 0,
					itemHeight = 0,
					itemContent = item.find('.eltdf-hspl-item-content'),
					itemContentSize = itemContent.outerHeight() + parseInt(itemContent.css('marginTop'), 10);
				
				if (!item.hasClass('eltdf-hspl-featured')) {
					
					if (count / 2 >= current) {
						
						if (current % 2 === 0) {
							itemWidth = 238;
							itemHeight = 356;
						} else {
							itemWidth = 284;
							itemHeight = 230;
							
							if (eltdf.windowWidth < 1401) {
								itemWidth = 234;
								itemHeight = 190;
							}
						}
					} else {
						
						if (current % 2 !== 0) {
							itemWidth = 284;
							itemHeight = 230;
							
							if (eltdf.windowWidth < 1401) {
								itemWidth = 234;
								itemHeight = 190;
							}
						} else {
							itemWidth = 238;
							itemHeight = 356;
						}
					}
					
					var sumWidth = itemWidth + currentInstance.spaceBetweenItems;
					var sumHeight = itemHeight + itemContentSize;
					var sumDifference = 0;
					
					if (sectionHeight / 2 < sumHeight) {
						sumDifference = Math.round(sumHeight - sectionHeight / 2);
						sumWidth = Math.round(sumWidth * (sumHeight - sumDifference) / sumHeight);
					}
					
					item.css({'width': sumWidth, 'height': sumHeight - sumDifference});
					
					listWidth += sumWidth;
				}
				
				current++;
			});
			
			if (eltdf.windowWidth <= 1680) {
				currentInstance.listInner.width((listWidth + 2 * currentInstance.spaceBetweenItems) / currentInstance.rowsNumber);
			} else {
				currentInstance.listInner.width((listWidth + currentInstance.spaceBetweenItems / 2) / currentInstance.rowsNumber);
			}
		},
		getHolderWidth: function (currentInstance) {
			return currentInstance.listInner.outerWidth() + currentInstance.widthValFeatured + currentInstance.spaceBetweenItems - eltdf.windowWidth;
		},
		touchDevicesInit: function (currentInstance) {
			var sectionH = new Hammer(currentInstance.section),
				transformVal = 0;
			
			var moveContent = function (delta) {
				currentInstance.listInner.css('transform', 'translate3d(' + delta + 'px, 0, 0)');
			};

			currentInstance.listInner.addClass('eltdf-ready');
			
			sectionH.on("swipe", function (ev) {
				if (ev.deltaX > 0) {
					transformVal += ev.distance;
					transformVal = Math.min(0, transformVal);
				} else {
					transformVal -= ev.distance;
					transformVal = -Math.min(currentInstance.getHolderWidth(currentInstance), Math.abs(transformVal));
				}
				
				moveContent(transformVal);
			});
		},
		devicesInit: function (currentInstance) {
			var targetX = 0,
				currentX = 0,
				ease = 0.08;
			
			eltdf.htmlEl.add(eltdf.body).addClass('eltdf-overflow-hidden');
			eltdf.modules.common.eltdfDisableScroll();
			currentInstance.listInner.addClass('eltdf-ready');
			
			VirtualScroll.on(function (e) {
				targetX += e.deltaY;
				targetX = Math.min(0, Math.max(currentInstance.getHolderWidth(currentInstance) * -1, targetX));
			});
			
			var animateOnScroll = function(items) {
				if (items.not('.eltdf-show').length) {
					items.not('.eltdf-show').each(function(){
						var item = $(this);
						item.offset().left - eltdf.windowWidth < 0 && item.addClass('eltdf-show');
					});
				}
			}
			
			var performScroll = function () {
				requestAnimationFrame(performScroll);
				currentX += (targetX - currentX) * ease;
				
				var t = 'translate3d(' + currentX + 'px, 0px, 0px)';
				var s = currentInstance.section.style;
				s["transform"] = t;
				s["webkitTransform"] = t;
				s["mozTransform"] = t;
				s["msTransform"] = t;
				
				animateOnScroll(currentInstance.items);
			};
			
			performScroll();
		}
	};
	
	/**
	 * Initializes hover effect
	 */
	function eltdfBlurImage() {
		eltdf.modules.common.eltdfBlurImage('.eltdf-horizontal-scrolling-portfolio-holder .eltdf-hspl-item-inner', '.eltdf-hspli-image img');
	}
	
	/**
	 * Initializes touch scroll animation
	 */
	function eltdfInitTouchAnimation(){
		var portList = $('.eltdf-horizontal-scrolling-portfolio-holder');
		
		if ( eltdf.windowWidth < 1025 ) {
			if (portList.length) {
				portList.each(function () {
					$(this).find('article').each(function() {
						var thisArticle = $(this);
						
						thisArticle.appear(function () {
							setTimeout(function () {
								thisArticle.addClass('eltdf-item-show');
							}, 150);
						});
					});
				});
			}
		}
	}
	
})(jQuery);