<?php
class SoleneCoreElementorHorizontalScrollingPortfolioList extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_horizontal_scrolling_portfolio_list'; 
	}

	public function get_title() {
		return esc_html__( 'Horizontal Scrolling Portfolio List', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-horizontal-scrolling-portfolio-list';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

    public function get_script_depends() {
        return array(
            'hammer',
            'virtual-scroll'
        );
    }

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'item_type',
			[
				'label'     => esc_html__( 'Click Behavior', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Open portfolio single page on click', 'solene-core'), 
					'gallery' => esc_html__( 'Open gallery in Pretty Photo on click', 'solene-core')
				),
				'default' => ''
			]
		);

		$this->add_control(
			'number_of_items',
			[
				'label'     => esc_html__( 'Number of Portfolios Per Page', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Set number of items for your portfolio list. Enter -1 to show all.', 'solene-core' ),
                'default'   => '-1'
			]
		);

		$this->add_control(
			'featured_project',
			[
				'label'     => esc_html__( 'Choose Featured Project', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'decrease_height_for_header',
			[
				'label'     => esc_html__( 'Decrease Height for Header Height', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$this->add_control(
			'decrease_height_for_content_bottom',
			[
				'label'     => esc_html__( 'Decrease Height for Content Bottom Widget Area', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$this->add_control(
			'additional_featured_image',
			[
				'label'     => esc_html__( 'Enable Additional Featured Image', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no'
			]
		);

		$this->add_control(
			'category',
			[
				'label'     => esc_html__( 'One-Category Portfolio List', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter one category slug (leave empty for showing all categories)', 'solene-core' )
			]
		);

		$this->add_control(
			'selected_projects',
			[
				'label'     => esc_html__( 'Show Only Projects with Listed IDs', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Delimit ID numbers by comma (leave empty for all)', 'solene-core' )
			]
		);

		$this->add_control(
			'tag',
			[
				'label'     => esc_html__( 'One-Tag Portfolio List', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter one tag slug (leave empty for showing all tags)', 'solene-core' )
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'     => esc_html__( 'Order By', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'date' => esc_html__( 'Date', 'solene-core'), 
					'ID' => esc_html__( 'ID', 'solene-core'), 
					'menu_order' => esc_html__( 'Menu Order', 'solene-core'), 
					'name' => esc_html__( 'Post Name', 'solene-core'), 
					'rand' => esc_html__( 'Random', 'solene-core'), 
					'title' => esc_html__( 'Title', 'solene-core')
				),
				'default' => 'date'
			]
		);

		$this->add_control(
			'order',
			[
				'label'     => esc_html__( 'Order', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'ASC' => esc_html__( 'ASC', 'solene-core'), 
					'DESC' => esc_html__( 'DESC', 'solene-core')
				),
				'default' => 'ASC'
			]
		);


		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();

		/***
		 * @params query_results
		 * @params holder_data
		 * @params holder_classes
		 * @params holder_inner_classes
		 */
		$additional_params = array();
		
		$query_array                        = $this->getQueryArray( $params );
		$query_results                      = new \WP_Query( $query_array );
		$additional_params['query_results'] = $query_results;
		
		$additional_params['holder_classes'] = $this->getHolderClasses( $params );
		$additional_params['holder_data']    = $this->getData( $params );
		$params['this_object'] = $this;

        echo solene_core_get_cpt_shortcode_module_template_part( 'portfolio', 'horizontal-scrolling-portfolio-list', 'portfolio-holder', '', $params, $additional_params );

	}

	private function getData( $params ) {
		$data = array();
		
		if ( $params['decrease_height_for_header'] == 'yes' ) {
			$data[] = 'data-header-decrease=yes';
		}
		
		if ( $params['decrease_height_for_content_bottom'] == 'yes' ) {
			$data[] = 'data-content-bottom-decrease=yes';
		}
		
		return implode( ' ', $data );
	}

	public function getQueryArray( $params ) {
		$query_array = array(
			'post_status'    => 'publish',
			'post_type'      => 'portfolio-item',
			'posts_per_page' => $params['number_of_items'],
			'orderby'        => $params['orderby'],
			'order'          => $params['order']
		);
		
		if ( ! empty( $params['category'] ) ) {
			$query_array['portfolio-category'] = $params['category'];
		}
		
		$project_ids = null;
		if ( ! empty( $params['selected_projects'] ) ) {
			$project_ids             = explode( ',', $params['selected_projects'] );
			$query_array['post__in'] = $project_ids;
		}
		
		//exclude featured project
		if ( ! empty( $params['featured_project'] ) ) {
			$query_array['post__not_in'] = array( $params['featured_project'] );
		}
		
		if ( ! empty( $params['tag'] ) ) {
			$query_array['portfolio-tag'] = $params['tag'];
		}
		
		if ( ! empty( $params['next_page'] ) ) {
			$query_array['paged'] = $params['next_page'];
		} else {
			$query_array['paged'] = 1;
		}
		
		return $query_array;
	}

	public function getHolderClasses( $params ) {
		$classes = array();

		$classes[] = ! empty( $params['featured_project'] ) ? 'eltdf-hsp-has-featured' : '';

		return implode( ' ', $classes );
	}

	public function getArticleClasses( $params ) {
		$classes = array();
		
		$original_image_proportion = get_post_meta( get_the_ID(), 'eltdf_portfolio_masonry_original_dimensions_meta', true );
		
		switch ( $original_image_proportion ) {
			case 'large-width':
				$classes[] = 'eltdf-hsp-landscape';
				break;
			default :
				$classes[] = 'eltdf-hsp-item';
				break;
		}
		
		$article_classes = get_post_class( $classes );
		
		return implode( ' ', $article_classes );
	}

	public function getItemLink( $params ) {
		$item_id = $params['is_featured'] ? $params['featured_project'] : get_the_ID();
		
		$portfolio_link_meta = get_post_meta( $item_id, 'portfolio_external_link', true );
		$portfolio_link      = ! empty( $portfolio_link_meta ) ? $portfolio_link_meta : get_permalink( $item_id );
		
		return apply_filters( 'solene_elated_filter_portfolio_external_link', $portfolio_link );
	}

	public function getItemLinkTarget( $params ) {
		$item_id = $params['is_featured'] ? $params['featured_project'] : get_the_ID();
		
		$portfolio_link_meta   = get_post_meta( $item_id, 'portfolio_external_link', true );
		$portfolio_link_target = ! empty( $portfolio_link_meta ) ? '_blank' : '_self';
		
		return apply_filters( 'solene_elated_filter_portfolio_external_link_target', $portfolio_link_target );
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorHorizontalScrollingPortfolioList() );