<?php
class SoleneCoreElementorPortfolioList extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_portfolio_list'; 
	}

	public function get_title() {
		return esc_html__( 'Portfolio List', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-portfolio-list';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'type',
			[
				'label'     => esc_html__( 'Portfolio List Template', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'gallery' => esc_html__( 'Gallery', 'solene-core'), 
					'masonry' => esc_html__( 'Masonry', 'solene-core'), 
					'exhibition' => esc_html__( 'Exhibition', 'solene-core')
				),
				'default' => 'gallery'
			]
		);

		$this->add_control(
			'orientation',
			[
				'label'     => esc_html__( 'Orientation', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'left' => esc_html__( 'Left', 'solene-core'), 
					'right' => esc_html__( 'Right', 'solene-core')
				),
				'default' => '',
				'condition' => [
					'type' => array( 'exhibition' )
				]
			]
		);

		$this->add_control(
			'item_type',
			[
				'label'     => esc_html__( 'Click Behavior', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Open portfolio single page on click', 'solene-core'), 
					'gallery' => esc_html__( 'Open gallery in Pretty Photo on click', 'solene-core')
				),
				'default' => ''
			]
		);

		$this->add_control(
			'number_of_columns',
			[
				'label'     => esc_html__( 'Number of Columns', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'Default value is Three', 'solene-core' ),
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'one' => esc_html__( 'One', 'solene-core'), 
					'two' => esc_html__( 'Two', 'solene-core'), 
					'three' => esc_html__( 'Three', 'solene-core'), 
					'four' => esc_html__( 'Four', 'solene-core'), 
					'five' => esc_html__( 'Five', 'solene-core'), 
					'six' => esc_html__( 'Six', 'solene-core')
				),
				'default' => 'three'
			]
		);

		$this->add_control(
			'space_between_items',
			[
				'label'     => esc_html__( 'Space Between Items', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'huge' => esc_html__( 'Huge (54)', 'solene-core'), 
					'large' => esc_html__( 'Large (25)', 'solene-core'), 
					'medium' => esc_html__( 'Medium (20)', 'solene-core'), 
					'normal' => esc_html__( 'Normal (15)', 'solene-core'), 
					'small' => esc_html__( 'Small (10)', 'solene-core'), 
					'tiny' => esc_html__( 'Tiny (5)', 'solene-core'), 
					'no' => esc_html__( 'No (0)', 'solene-core')
				),
				'default' => 'tiny',
				'condition' => [
					'type' => array( 'gallery', 'masonry' )
				]
			]
		);

		$this->add_control(
			'number_of_items',
			[
				'label'     => esc_html__( 'Number of Portfolios Per Page', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Set number of items for your portfolio list. Enter -1 to show all.', 'solene-core' )
			]
		);

		$this->add_control(
			'image_proportions',
			[
				'label'     => esc_html__( 'Image Proportions', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'Set image proportions for your portfolio list.', 'solene-core' ),
				'options' => array(
					'full' => esc_html__( 'Original', 'solene-core'), 
					'square' => esc_html__( 'Square', 'solene-core'), 
					'landscape' => esc_html__( 'Landscape', 'solene-core'), 
					'portrait' => esc_html__( 'Portrait', 'solene-core'), 
					'medium' => esc_html__( 'Medium', 'solene-core'), 
					'large' => esc_html__( 'Large', 'solene-core'), 
					'custom' => esc_html__( 'Custom', 'solene-core')
				),
				'default' => 'full',
				'condition' => [
					'type' => array( 'gallery' )
				]
			]
		);

		$this->add_control(
			'custom_image_width',
			[
				'label'     => esc_html__( 'Custom Image Width', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter image width in px', 'solene-core' ),
				'condition' => [
					'image_proportions' => array( 'custom' )
				]
			]
		);

		$this->add_control(
			'custom_image_height',
			[
				'label'     => esc_html__( 'Custom Image Height', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter image height in px', 'solene-core' ),
				'condition' => [
					'image_proportions' => array( 'custom' )
				]
			]
		);

		$this->add_control(
			'enable_fixed_proportions',
			[
				'label'     => esc_html__( 'Enable Fixed Image Proportions', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'Set predefined image proportions for your masonry portfolio list. This option will apply image proportions you set in Portfolio Single page - dimensions for masonry option.', 'solene-core' ),
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no',
				'condition' => [
					'type' => array( 'masonry' )
				]
			]
		);

		$this->add_control(
			'enable_padding',
			[
				'label'     => esc_html__( 'Enable Padding', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'This option will apply padding you set in Portfolio Single page - Padding for Masonry List.', 'solene-core' ),
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no',
				'condition' => [
					'type' => array( 'masonry' )
				]
			]
		);

		$this->add_control(
			'disable_padding_on_mobile',
			[
				'label'     => esc_html__( 'Disable Padding On Mobile Devices', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'This option will disable padding you set in Portfolio Single page - Padding for Masonry List, on Mobile devices.', 'solene-core' ),
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes',
				'condition' => [
					'enable_padding' => array( 'yes' )
				]
			]
		);

		$this->add_control(
			'enable_image_shadow',
			[
				'label'     => esc_html__( 'Enable Image Shadow', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no'
			]
		);

		$this->add_control(
			'category',
			[
				'label'     => esc_html__( 'One-Category Portfolio List', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter one category slug (leave empty for showing all categories)', 'solene-core' )
			]
		);

		$this->add_control(
			'selected_projects',
			[
				'label'     => esc_html__( 'Show Only Projects with Listed IDs', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Delimit ID numbers by comma (leave empty for all)', 'solene-core' )
			]
		);

		$this->add_control(
			'tag',
			[
				'label'     => esc_html__( 'One-Tag Portfolio List', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter one tag slug (leave empty for showing all tags)', 'solene-core' )
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'     => esc_html__( 'Order By', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'date' => esc_html__( 'Date', 'solene-core'), 
					'ID' => esc_html__( 'ID', 'solene-core'), 
					'menu_order' => esc_html__( 'Menu Order', 'solene-core'), 
					'name' => esc_html__( 'Post Name', 'solene-core'), 
					'rand' => esc_html__( 'Random', 'solene-core'), 
					'title' => esc_html__( 'Title', 'solene-core')
				),
				'default' => 'date'
			]
		);

		$this->add_control(
			'order',
			[
				'label'     => esc_html__( 'Order', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'ASC' => esc_html__( 'ASC', 'solene-core'), 
					'DESC' => esc_html__( 'DESC', 'solene-core')
				),
				'default' => 'ASC'
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_layout',
			[
				'label' => esc_html__( 'Content Layout', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'item_style',
			[
				'label'     => esc_html__( 'Item Style', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'standard' => esc_html__( 'Standard - Zoom Out', 'solene-core'), 
					'standard-move' => esc_html__( 'Standard - Move', 'solene-core'), 
					'gallery-overlay' => esc_html__( 'Gallery - Overlay', 'solene-core'), 
					'gallery-overlay-predefined' => esc_html__( 'Gallery - Overlay Predefined', 'solene-core')
				),
				'default' => 'standard'
			]
		);

		$this->add_control(
			'content_top_margin',
			[
				'label'     => esc_html__( 'Content Top Margin (px or %)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'item_style' => array( 'standard', 'standard-switch-images' )
				]
			]
		);

		$this->add_control(
			'content_bottom_margin',
			[
				'label'     => esc_html__( 'Content Bottom Margin (px or %)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'item_style' => array( 'standard' )
				]
			]
		);

		$this->add_control(
			'enable_title',
			[
				'label'     => esc_html__( 'Enable Title', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'     => esc_html__( 'Title Tag', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'h1' => esc_html__( 'h1', 'solene-core'), 
					'h2' => esc_html__( 'h2', 'solene-core'), 
					'h3' => esc_html__( 'h3', 'solene-core'), 
					'h4' => esc_html__( 'h4', 'solene-core'), 
					'h5' => esc_html__( 'h5', 'solene-core'), 
					'h6' => esc_html__( 'h6', 'solene-core')
				),
				'default' => 'h3',
				'condition' => [
					'enable_title' => array( 'yes' )
				]
			]
		);

		$this->add_control(
			'title_text_transform',
			[
				'label'     => esc_html__( 'Title Text Transform', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'none' => esc_html__( 'None', 'solene-core'), 
					'capitalize' => esc_html__( 'Capitalize', 'solene-core'), 
					'uppercase' => esc_html__( 'Uppercase', 'solene-core'), 
					'lowercase' => esc_html__( 'Lowercase', 'solene-core'), 
					'initial' => esc_html__( 'Initial', 'solene-core'), 
					'inherit' => esc_html__( 'Inherit', 'solene-core')
				),
				'default' => '',
				'condition' => [
					'enable_title' => array( 'yes' )
				]
			]
		);

		$this->add_control(
			'enable_category',
			[
				'label'     => esc_html__( 'Enable Category', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$this->add_control(
			'enable_count_images',
			[
				'label'     => esc_html__( 'Enable Number of Images', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes',
				'condition' => [
					'type' => array( 'gallery' )
				]
			]
		);

		$this->add_control(
			'enable_excerpt',
			[
				'label'     => esc_html__( 'Enable Excerpt', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no'
			]
		);

		$this->add_control(
			'excerpt_length',
			[
				'label'     => esc_html__( 'Excerpt Length', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Number of characters', 'solene-core' ),
				'condition' => [
					'enable_excerpt' => array( 'yes' )
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'additional_features',
			[
				'label' => esc_html__( 'Additional Features', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'pagination_type',
			[
				'label'     => esc_html__( 'Pagination Type', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'no-pagination' => esc_html__( 'None', 'solene-core'), 
					'standard' => esc_html__( 'Standard', 'solene-core'), 
					'load-more' => esc_html__( 'Load More', 'solene-core'), 
					'infinite-scroll' => esc_html__( 'Infinite Scroll', 'solene-core')
				),
				'default' => 'no-pagination'
			]
		);

		$this->add_control(
			'load_more_top_margin',
			[
				'label'     => esc_html__( 'Load More Top Margin (px or %)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'pagination_type' => array( 'load-more' )
				]
			]
		);

		$this->add_control(
			'filter',
			[
				'label'     => esc_html__( 'Enable Category Filter', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no'
			]
		);

		$this->add_control(
			'filter_order_by',
			[
				'label'     => esc_html__( 'Filter Order By', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'name' => esc_html__( 'Name', 'solene-core'), 
					'count' => esc_html__( 'Count', 'solene-core'), 
					'id' => esc_html__( 'Id', 'solene-core'), 
					'slug' => esc_html__( 'Slug', 'solene-core')
				),
				'default' => 'name',
				'condition' => [
					'filter' => array( 'yes' )
				]
			]
		);

		$this->add_control(
			'filter_text_transform',
			[
				'label'     => esc_html__( 'Filter Text Transform', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'none' => esc_html__( 'None', 'solene-core'), 
					'capitalize' => esc_html__( 'Capitalize', 'solene-core'), 
					'uppercase' => esc_html__( 'Uppercase', 'solene-core'), 
					'lowercase' => esc_html__( 'Lowercase', 'solene-core'), 
					'initial' => esc_html__( 'Initial', 'solene-core'), 
					'inherit' => esc_html__( 'Inherit', 'solene-core')
				),
				'default' => '',
				'condition' => [
					'filter' => array( 'yes' )
				]
			]
		);

		$this->add_control(
			'filter_bottom_margin',
			[
				'label'     => esc_html__( 'Filter Bottom Margin (px or %)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'filter' => array( 'yes' )
				]
			]
		);

		$this->add_control(
			'enable_article_animation',
			[
				'label'     => esc_html__( 'Enable Article Animation', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'Enabling this option you will enable appears animation for your portfolio list items', 'solene-core' ),
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no'
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'main_section',
			[
				'label' => esc_html__( 'Main Section', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'main_image',
			[
				'label'     => esc_html__( 'Main Image', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA,
				'description' => esc_html__( 'Select image from media library', 'solene-core' ),
				'condition' => [
					'type' => array( 'exhibition' )
				]
			]
		);

		$this->add_control(
			'main_title',
			[
				'label'     => esc_html__( 'Main Title', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'main_image!' => ''
				]
			]
		);

		$this->add_control(
			'main_title_tag',
			[
				'label'     => esc_html__( 'Main Title Tag', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'h1' => esc_html__( 'h1', 'solene-core'), 
					'h2' => esc_html__( 'h2', 'solene-core'), 
					'h3' => esc_html__( 'h3', 'solene-core'), 
					'h4' => esc_html__( 'h4', 'solene-core'), 
					'h5' => esc_html__( 'h5', 'solene-core'), 
					'h6' => esc_html__( 'h6', 'solene-core')
				),
				'default' => 'h3',
				'condition' => [
					'main_title!' => ''
				]
			]
		);

		$this->add_control(
			'tagline',
			[
				'label'     => esc_html__( 'Tagline', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'main_title!' => ''
				]
			]
		);

		$this->add_control(
			'tagline_margin',
			[
				'label'     => esc_html__( 'Tagline Bottom Margin (px)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'tagline!' => ''
				]
			]
		);

		$this->add_control(
			'link',
			[
				'label'     => esc_html__( 'Link', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'main_image!' => ''
				]
			]
		);

		$this->add_control(
			'target',
			[
				'label'     => esc_html__( 'Link Target', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'_self' => esc_html__( 'Same Window', 'solene-core'), 
					'_blank' => esc_html__( 'New Window', 'solene-core')
				),
				'default' => '_self',
				'condition' => [
					'link!' => ''
				]
			]
		);


		$this->end_controls_section();
	}
	public function render() {
        $args   = array(
            'type'                      => 'gallery',
            'item_type'                 => '',
            'number_of_columns'         => 'three',
            'space_between_items'       => 'tiny',
            'number_of_items'           => '-1',
            'image_proportions'         => 'full',
            'custom_image_width'        => '',
            'custom_image_height'       => '',
            'enable_fixed_proportions'  => 'no',
            'enable_padding'            => 'no',
            'disable_padding_on_mobile' => 'yes',
            'enable_image_shadow'       => 'no',
            'category'                  => '',
            'selected_projects'         => '',
            'tag'                       => '',
            'orderby'                   => 'date',
            'order'                     => 'ASC',
            'item_style'                => 'standard',
            'content_top_margin'        => '',
            'content_bottom_margin'     => '',
            'enable_title'              => 'yes',
            'title_tag'                 => 'h3',
            'title_text_transform'      => '',
            'enable_category'           => 'yes',
            'enable_count_images'       => 'yes',
            'enable_excerpt'            => 'no',
            'excerpt_length'            => '20',
            'pagination_type'           => 'no-pagination',
            'load_more_top_margin'      => '',
            'filter'                    => 'no',
            'filter_order_by'           => 'name',
            'filter_text_transform'     => '',
            'filter_bottom_margin'      => '',
            'enable_article_animation'  => 'no',
            'portfolio_slider_on'       => 'no',
            'enable_loop'               => 'yes',
            'enable_autoplay'           => 'yes',
            'slider_speed'              => '5000',
            'slider_speed_animation'    => '600',
            'enable_navigation'         => 'yes',
            'navigation_skin'           => '',
            'enable_pagination'         => 'yes',
            'pagination_skin'           => '',
            'pagination_position'       => '',
            'orientation'               => '',
            'main_image'                => '',
            'main_title'                => '',
            'main_title_tag'            => 'h3',
            'tagline'                   => '',
            'tagline_margin'            => '',
            'link'                      => '',
            'target'                    => '_self'
        );
        $params = shortcode_atts( $args, $this->get_settings_for_display() );


		$params['main_image'] = !empty($params['main_image']['id']) ? $params['main_image']['id'] : '';
		$params['tagline']	  = !empty($params['tagline']) ? $params['tagline'] : '';
		$params['tagline_margin']	  = !empty($params['tagline_margin']) ? $params['tagline_margin'] : '';
		$params['main_section_bg_styles'] = $this->getBackgroundImageStyles( $params['main_image'] );
		$params['main_title_tag'] = ! empty( $params['main_title_tag'] ) ? $params['main_title_tag'] : 'h3';
		$params['tagline_styles'] = $this->getTaglineStyles( $params );
		
		/***
		 * @params query_results
		 * @params holder_data
		 * @params holder_classes
		 * @params holder_inner_classes
		 */
		$additional_params = array();
		
		$query_array                        = $this->getQueryArray( $params );
		$query_results                      = new \WP_Query( $query_array );
		$additional_params['query_results'] = $query_results;
		
		$additional_params['holder_data']          = solene_elated_get_holder_data_for_cpt( $params, $additional_params );
		$additional_params['holder_classes']       = $this->getHolderClasses( $params, $args );
		$additional_params['holder_inner_classes'] = $this->getHolderInnerClasses( $params );
		
		$params['this_object'] = $this;

        echo solene_core_get_cpt_shortcode_module_template_part( 'portfolio', 'portfolio-list', 'portfolio-holder', $params['type'], $params, $additional_params );

	}

	public function getQueryArray( $params ) {
		$query_array = array(
			'post_status'    => 'publish',
			'post_type'      => 'portfolio-item',
			'posts_per_page' => $params['number_of_items'],
			'orderby'        => $params['orderby'],
			'order'          => $params['order']
		);
		
		if ( ! empty( $params['category'] ) ) {
			$query_array['portfolio-category'] = $params['category'];
		}
		
		$project_ids = null;
		if ( ! empty( $params['selected_projects'] ) ) {
			$project_ids             = explode( ',', $params['selected_projects'] );
            $query_array['orderby'] = 'post__in';
			$query_array['post__in'] = $project_ids;
		}
		
		if ( ! empty( $params['tag'] ) ) {
			$query_array['portfolio-tag'] = $params['tag'];
		}
		
		if ( ! empty( $params['next_page'] ) ) {
			$query_array['paged'] = $params['next_page'];
		} else {
			$query_array['paged'] = 1;
		}
		
		return $query_array;
	}

	public function getHolderClasses( $params, $args ) {
		$classes = array();
		
		$classes[] = ! empty( $params['type'] ) ? 'eltdf-pl-' . $params['type'] : 'eltdf-pl-' . $args['type'];
		$classes[] = ! empty( $params['number_of_columns'] ) ? 'eltdf-' . $params['number_of_columns'] . '-columns' : 'eltdf-' . $args['number_of_columns'] . '-columns';
		$classes[] = ! empty( $params['space_between_items'] ) && ($params['type'] !== 'exhibition') ? 'eltdf-' . $params['space_between_items'] . '-space' : 'eltdf-' . $args['space_between_items'] . '-space';
		$classes[] = ! in_array( $params['pagination_type'], array( 'standard-shortcodes', 'load-more' ) ) ? 'eltdf-disable-bottom-space' : '';
		$classes[] = ! empty( $params['item_style'] ) ? 'eltdf-pl-' . $params['item_style'] : '';
		$classes[] = $params['disable_padding_on_mobile'] === 'yes' ? 'eltdf-pip-disabled' : '';
		$classes[] = $params['enable_fixed_proportions'] === 'yes' ? 'eltdf-fixed-masonry-items' : '';
		$classes[] = $params['enable_image_shadow'] === 'yes' ? 'eltdf-pl-has-shadow' : '';
		$classes[] = $params['enable_title'] === 'no' && $params['enable_category'] === 'no' && $params['enable_excerpt'] === 'no' ? 'eltdf-pl-no-content' : '';
		$classes[] = ! empty( $params['pagination_type'] ) ? 'eltdf-pl-pag-' . $params['pagination_type'] : '';
		$classes[] = $params['filter'] === 'yes' ? 'eltdf-pl-has-filter' : '';
		$classes[] = $params['enable_article_animation'] === 'yes' ? 'eltdf-pl-has-animation' : '';
		$classes[] = ! empty( $params['navigation_skin'] ) ? 'eltdf-nav-' . $params['navigation_skin'] . '-skin' : '';
		$classes[] = ! empty( $params['pagination_skin'] ) ? 'eltdf-pag-' . $params['pagination_skin'] . '-skin' : '';
		$classes[] = ! empty( $params['pagination_position'] ) ? 'eltdf-pag-' . $params['pagination_position'] : '';
		$classes[] = ! empty( $params['orientation'] ) ? 'eltdf-orientation-' . $params['orientation'] : '';
		
		return implode( ' ', $classes );
	}

	public function getHolderInnerClasses( $params ) {
		$classes = array();
		
		$classes[] = $params['portfolio_slider_on'] === 'yes' ? 'eltdf-owl-slider eltdf-list-is-slider' : '';
		
		return implode( ' ', $classes );
	}

	public function getArticleClasses( $params ) {
		$classes = array();
		
		$type       = $params['type'];
		
		$image_proportion = $params['enable_fixed_proportions'] === 'yes' ? 'fixed' : 'original';
		$masonry_size     = get_post_meta( get_the_ID(), 'eltdf_portfolio_masonry_' . $image_proportion . '_dimensions_meta', true );
		
		$classes[] = ! empty( $masonry_size ) && $type === 'masonry' ? 'eltdf-masonry-size-' . esc_attr( $masonry_size ) : '';
		
		$article_classes = get_post_class( $classes );
		
		return implode( ' ', $article_classes );
	}

	private function getBackgroundImageStyles( $image ) {
		$styles = array();
		
		if ( ! empty( $image ) ) {
			$image_original = wp_get_attachment_image_src( $image, 'full' );
			
			$styles[] = 'background-image: url(' . $image_original[0] . ')';
			$styles[] = 'background-repeat: no-repeat';
			$styles[] = 'background-size: cover';
		}
		
		return implode( ';', $styles );
	}

	private function getTaglineStyles( $params ) {
		$styles = array();
		
		if ( $params['tagline_margin'] !== '' ) {
			$styles[] = 'margin-bottom: ' . solene_elated_filter_px( $params['tagline_margin'] ) . 'px';
		}
		
		return implode( ';', $styles );
	}

	public function getImageSize( $params ) {
		$thumb_size = 'full';
		
		if ( ! empty( $params['image_proportions'] ) && $params['type'] == 'gallery' ) {
			$image_size = $params['image_proportions'];
			
			switch ( $image_size ) {
				case 'landscape':
					$thumb_size = 'solene_elated_image_landscape';
					break;
				case 'portrait':
					$thumb_size = 'solene_elated_image_portrait';
					break;
				case 'square':
					$thumb_size = 'solene_elated_image_square';
					break;
				case 'medium':
					$thumb_size = 'medium';
					break;
				case 'large':
					$thumb_size = 'large';
					break;
				case 'full':
					$thumb_size = 'full';
					break;
				case 'custom':
					$thumb_size = 'custom';
					break;
			}
		}
		
		if ( $params['type'] == 'masonry' && $params['enable_fixed_proportions'] === 'yes' ) {
			$fixed_image_size = get_post_meta( get_the_ID(), 'eltdf_portfolio_masonry_fixed_dimensions_meta', true );
			
			switch ( $fixed_image_size ) {
				case 'small' :
					$thumb_size = 'solene_elated_image_square';
					break;
				case 'large-width':
					$thumb_size = 'solene_elated_image_landscape';
					break;
				case 'large-height':
					$thumb_size = 'solene_elated_image_portrait';
					break;
				case 'large-width-height':
					$thumb_size = 'solene_elated_image_huge';
					break;
				default :
					$thumb_size = 'full';
					break;
			}
		}
		
		return $thumb_size;
	}

	public function getStandardContentStyles( $params ) {
		$styles = array();
		
		$margin_top    = isset( $params['content_top_margin'] ) ? $params['content_top_margin'] : '';
		$margin_bottom = isset( $params['content_bottom_margin'] ) ? $params['content_bottom_margin'] : '';
		
		if ( ! empty( $margin_top ) ) {
			if ( solene_elated_string_ends_with( $margin_top, '%' ) || solene_elated_string_ends_with( $margin_top, 'px' ) ) {
				$styles[] = 'margin-top: ' . $margin_top;
			} else {
				$styles[] = 'margin-top: ' . solene_elated_filter_px( $margin_top ) . 'px';
			}
		}
		
		if ( ! empty( $margin_bottom ) ) {
			if ( solene_elated_string_ends_with( $margin_bottom, '%' ) || solene_elated_string_ends_with( $margin_bottom, 'px' ) ) {
				$styles[] = 'margin-bottom: ' . $margin_bottom;
			} else {
				$styles[] = 'margin-bottom: ' . solene_elated_filter_px( $margin_bottom ) . 'px';
			}
		}
		
		return implode( ';', $styles );
	}

	public function getTitleStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['title_text_transform'] ) ) {
			$styles[] = 'text-transform: ' . $params['title_text_transform'];
		}
		
		return implode( ';', $styles );
	}

	public function getLoadMoreStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['load_more_top_margin'] ) ) {
			$margin = $params['load_more_top_margin'];
			
			if ( solene_elated_string_ends_with( $margin, '%' ) || solene_elated_string_ends_with( $margin, 'px' ) ) {
				$styles[] = 'margin-top: ' . $margin;
			} else {
				$styles[] = 'margin-top: ' . solene_elated_filter_px( $margin ) . 'px';
			}
		}
		
		return implode( ';', $styles );
	}

	public function getFilterCategories( $params ) {
		$cat_id = 0;
		
		if ( ! empty( $params['category'] ) ) {
			$top_category = get_term_by( 'slug', $params['category'], 'portfolio-category' );
			
			if ( isset( $top_category->term_id ) ) {
				$cat_id = $top_category->term_id;
			}
		}
		
		$order = $params['filter_order_by'] === 'count' ? 'DESC' : 'ASC';
		
		$args = array(
			'taxonomy' => 'portfolio-category',
			'child_of' => $cat_id,
			'orderby'  => $params['filter_order_by'],
			'order'    => $order
		);
		
		$filter_categories = get_terms( $args );
		
		return $filter_categories;
	}

	public function getFilterHolderStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['filter_bottom_margin'] ) ) {
			$margin = $params['filter_bottom_margin'];
			
			if ( solene_elated_string_ends_with( $margin, '%' ) || solene_elated_string_ends_with( $margin, 'px' ) ) {
				$styles[] = 'margin-bottom: ' . $margin;
			} else {
				$styles[] = 'margin-bottom: ' . solene_elated_filter_px( $margin ) . 'px';
			}
		}
		
		return implode( ';', $styles );
	}

	public function getFilterStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['filter_text_transform'] ) ) {
			$styles[] = 'text-transform: ' . $params['filter_text_transform'];
		}
		
		return implode( ';', $styles );
	}

	public function getItemLink() {
		$portfolio_link_meta = get_post_meta( get_the_ID(), 'portfolio_external_link', true );
		$portfolio_link      = ! empty( $portfolio_link_meta ) ? $portfolio_link_meta : get_permalink( get_the_ID() );
		
		return apply_filters( 'solene_elated_filter_portfolio_external_link', $portfolio_link );
	}

	public function getItemLinkTarget() {
		$portfolio_link_meta   = get_post_meta( get_the_ID(), 'portfolio_external_link', true );
		$portfolio_link_target = ! empty( $portfolio_link_meta ) ? '_blank' : '_self';
		
		return apply_filters( 'solene_elated_filter_portfolio_external_link_target', $portfolio_link_target );
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorPortfolioList() );