<?php
class SoleneCoreElementorPortfolioSliderFullScreen extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_portfolio_slider_full_screen'; 
	}

	public function get_title() {
		return esc_html__( 'Portfolio Slider - Full Screen', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-portfolio-slider-full-screen';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'number_of_items',
			[
				'label'     => esc_html__( 'Number of Portfolios Items', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Set number of items for your portfolio slider. Enter -1 to show all', 'solene-core' )
			]
		);

		$this->add_control(
			'button_link_target',
			[
				'label'     => esc_html__( 'Button Target', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'_self' => esc_html__( 'Same Window', 'solene-core'), 
					'_blank' => esc_html__( 'New Window', 'solene-core')
				),
				'default' => '_self'
			]
		);

		$this->add_control(
			'category',
			[
				'label'     => esc_html__( 'One-Category Portfolio List', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter one category slug (leave empty for showing all categories)', 'solene-core' )
			]
		);

		$this->add_control(
			'selected_projects',
			[
				'label'     => esc_html__( 'Show Only Projects with Listed IDs', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Delimit ID numbers by comma (leave empty for all)', 'solene-core' )
			]
		);

		$this->add_control(
			'tag',
			[
				'label'     => esc_html__( 'One-Tag Portfolio List', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter one tag slug (leave empty for showing all tags)', 'solene-core' )
			]
		);

		$this->add_control(
			'order_by',
			[
				'label'     => esc_html__( 'Order By', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'date' => esc_html__( 'Date', 'solene-core'), 
					'ID' => esc_html__( 'ID', 'solene-core'), 
					'menu_order' => esc_html__( 'Menu Order', 'solene-core'), 
					'name' => esc_html__( 'Post Name', 'solene-core'), 
					'rand' => esc_html__( 'Random', 'solene-core'), 
					'title' => esc_html__( 'Title', 'solene-core')
				),
				'default' => 'date'
			]
		);

		$this->add_control(
			'order',
			[
				'label'     => esc_html__( 'Order', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'ASC' => esc_html__( 'ASC', 'solene-core'), 
					'DESC' => esc_html__( 'DESC', 'solene-core')
				),
				'default' => 'ASC'
			]
		);

		$this->add_control(
			'portfolio_info_skin',
			[
				'label'     => esc_html__( 'Portfolio Info Skin', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'light' => esc_html__( 'Light', 'solene-core')
				),
				'default' => ''
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'slider_settings',
			[
				'label' => esc_html__( 'Slider Settings', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'number_of_visible_items',
			[
				'label'     => esc_html__( 'Number Of Visible Items', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'1' => esc_html__( 'One', 'solene-core'), 
					'2' => esc_html__( 'Two', 'solene-core'), 
					'3' => esc_html__( 'Three', 'solene-core'), 
					'4' => esc_html__( 'Four', 'solene-core'), 
					'5' => esc_html__( 'Five', 'solene-core'), 
					'6' => esc_html__( 'Six', 'solene-core')
				),
				'default' => '4'
			]
		);

		$this->add_control(
			'space_between_items',
			[
				'label'     => esc_html__( 'Space Between Items', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'huge' => esc_html__( 'Huge (54)', 'solene-core'), 
					'large' => esc_html__( 'Large (25)', 'solene-core'), 
					'medium' => esc_html__( 'Medium (20)', 'solene-core'), 
					'normal' => esc_html__( 'Normal (15)', 'solene-core'), 
					'small' => esc_html__( 'Small (10)', 'solene-core'), 
					'tiny' => esc_html__( 'Tiny (5)', 'solene-core'), 
					'no' => esc_html__( 'No (0)', 'solene-core')
				),
				'default' => 'normal'
			]
		);

		$this->add_control(
			'enable_loop',
			[
				'label'     => esc_html__( 'Enable Slider Loop', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no'
			]
		);

		$this->add_control(
			'enable_autoplay',
			[
				'label'     => esc_html__( 'Enable Slider Autoplay', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$this->add_control(
			'slider_speed',
			[
				'label'     => esc_html__( 'Slide Duration', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Default value is 5000 (ms)', 'solene-core' )
			]
		);

		$this->add_control(
			'slider_speed_animation',
			[
				'label'     => esc_html__( 'Slide Animation Duration', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Speed of slide animation in milliseconds. Default value is 600.', 'solene-core' )
			]
		);

		$this->add_control(
			'enable_mousewheel_scroll',
			[
				'label'     => esc_html__( 'Enable Mousewheel Scroll', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no'
			]
		);

		$this->add_control(
			'enable_navigation',
			[
				'label'     => esc_html__( 'Enable Slider Navigation', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no'
			]
		);

		$this->add_control(
			'navigation_skin',
			[
				'label'     => esc_html__( 'Navigation Skin', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'light' => esc_html__( 'Light', 'solene-core')
				),
				'default' => '',
				'condition' => [
					'enable_navigation' => array( 'yes' )
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_layout',
			[
				'label' => esc_html__( 'Content Layout', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'display_title',
			[
				'label'     => esc_html__( 'Display Title', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'     => esc_html__( 'Title Tag', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'h1' => esc_html__( 'h1', 'solene-core'), 
					'h2' => esc_html__( 'h2', 'solene-core'), 
					'h3' => esc_html__( 'h3', 'solene-core'), 
					'h4' => esc_html__( 'h4', 'solene-core'), 
					'h5' => esc_html__( 'h5', 'solene-core'), 
					'h6' => esc_html__( 'h6', 'solene-core')
				),
				'default' => 'h3',
				'condition' => [
					'enable_title' => array( 'yes' )
				]
			]
		);

		$this->add_control(
			'title_text_transform',
			[
				'label'     => esc_html__( 'Title Text Transform', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'none' => esc_html__( 'None', 'solene-core'), 
					'capitalize' => esc_html__( 'Capitalize', 'solene-core'), 
					'uppercase' => esc_html__( 'Uppercase', 'solene-core'), 
					'lowercase' => esc_html__( 'Lowercase', 'solene-core'), 
					'initial' => esc_html__( 'Initial', 'solene-core'), 
					'inherit' => esc_html__( 'Inherit', 'solene-core')
				),
				'default' => 'uppercase',
				'condition' => [
					'enable_title' => array( 'yes' )
				]
			]
		);

		$this->add_control(
			'display_category',
			[
				'label'     => esc_html__( 'Display Category', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$this->add_control(
			'display_button',
			[
				'label'     => esc_html__( 'Display Button', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);


		$this->end_controls_section();
	}
	public function render() {
        $args = array(
            'number_of_items'          => '9',
            'number_of_visible_items'  => '4',
            'space_between_items'      => 'normal',
            'display_title'            => 'yes',
            'title_tag'                => 'h3',
            'title_text_transform'     => 'uppercase',
            'display_category'         => 'yes',
            'display_button'           => 'yes',
            'button_link_target'       => '',
            'category'                 => '',
            'selected_projects'        => '',
            'tag'                      => '',
            'order_by'                 => 'date',
            'enable_mousewheel_scroll' => 'no',
            'order'                    => 'ASC',
            'portfolio_info_skin'      => '',
            'enable_loop'              => 'no',
            'enable_autoplay'          => 'yes',
            'slider_speed'             => '5000',
            'slider_speed_animation'   => '600',
            'enable_navigation'        => 'no',
            'navigation_skin'          => ''
        );
        $params            = shortcode_atts( $args, $this->get_settings_for_display() );
		$additional_params = array();
		
		$query_array                         = $this->getQueryArray( $params );
		$query_results                       = new \WP_Query( $query_array );
		$additional_params['query_results']  = $query_results;
		$additional_params['holder_classes'] = $this->getHolderClasses( $params, $args );
		$additional_params['slider_data']    = $this->getSliderData( $params, $args );
		
		$params['this_object'] = $this;

        echo solene_core_get_cpt_shortcode_module_template_part( 'portfolio', 'portfolio-slider-full-screen', 'portfolio-holder', 'slider-full-screen', $params, $additional_params );
	}

	public function getQueryArray( $params ) {
		$query_array = array(
			'post_status'    => 'publish',
			'post_type'      => 'portfolio-item',
			'posts_per_page' => $params['number_of_items'],
			'orderby'        => $params['order_by'],
			'order'          => $params['order']
		);
		
		if ( ! empty( $params['category'] ) ) {
			$query_array['portfolio-category'] = $params['category'];
		}
		
		$project_ids = null;
		if ( ! empty( $params['selected_projects'] ) ) {
			$project_ids             = explode( ',', $params['selected_projects'] );
			$query_array['post__in'] = $project_ids;
		}
		
		if ( ! empty( $params['tag'] ) ) {
			$query_array['portfolio-tag'] = $params['tag'];
		}
		
		if ( ! empty( $params['next_page'] ) ) {
			$query_array['paged'] = $params['next_page'];
		} else {
			$query_array['paged'] = 1;
		}
		
		return $query_array;
	}

	public function getHolderClasses( $params, $args ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['portfolio_info_skin'] ) ? 'eltdf-info-' . $params['portfolio_info_skin'] . '-skin' : '';
		$holderClasses[] = ! empty( $params['navigation_skin'] ) ? 'eltdf-nav-' . $params['navigation_skin'] . '-skin' : '';
		$holderClasses[] = ! empty( $params['space_between_items'] ) ? 'eltdf-' . $params['space_between_items'] . '-space' : 'eltdf-' . $args['space_between_items'] . '-space';
		$holderClasses[] = $params['enable_mousewheel_scroll'] === 'yes' ? 'eltdf-pl-mousewheel-enabled' : '';
		
		return implode( ' ', $holderClasses );
	}

	public function getSliderData( $params, $args ) {
		$slider_data = array();
		
		$slider_data['data-number-of-items']        = $params['number_of_visible_items'] !== '' ? $params['number_of_visible_items'] : '4';
		$slider_data['data-enable-loop']            = ! empty( $params['enable_loop'] ) ? $params['enable_loop'] : $args['enable_loop'];
		$slider_data['data-enable-autoplay']        = ! empty( $params['enable_autoplay'] ) ? $params['enable_autoplay'] : $args['enable_autoplay'];
		$slider_data['data-slider-speed']           = ! empty( $params['slider_speed'] ) ? $params['slider_speed'] : $args['slider_speed'];
		$slider_data['data-slider-speed-animation'] = ! empty( $params['slider_speed_animation'] ) ? $params['slider_speed_animation'] : $args['slider_speed_animation'];
		$slider_data['data-slider-animate-in']      = 'fadeIn';
		$slider_data['data-slider-animate-out']     = 'fadeOut';
		$slider_data['data-enable-navigation']      = ! empty( $params['enable_navigation'] ) ? $params['enable_navigation'] : $args['enable_navigation'];
		
		return $slider_data;
	}

	public function getItemLink() {
		$portfolio_link_meta = get_post_meta( get_the_ID(), 'portfolio_external_link', true );
		$portfolio_link = ! empty( $portfolio_link_meta ) ? $portfolio_link_meta : get_permalink( get_the_ID() );
		
		return apply_filters( 'solene_elated_filter_portfolio_external_link', $portfolio_link );
	}

	public function getTitleStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['title_text_transform'] ) ) {
			$styles[] = 'text-transform: ' . $params['title_text_transform'];
		}
		
		return implode( ';', $styles );
	}

	public function getItemLinkTarget() {
		$portfolio_link_meta = get_post_meta( get_the_ID(), 'portfolio_external_link', true );
		
		$portfolio_link_target = ! empty( $portfolio_link_meta ) ? '_blank' : '_self';
		
		return apply_filters( 'solene_elated_filter_portfolio_external_link_target', $portfolio_link_target );
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorPortfolioSliderFullScreen() );