<?php

if ( ! function_exists( 'solene_core_proofing_gallery_meta_box_functions' ) ) {
	function solene_core_proofing_gallery_meta_box_functions( $post_types ) {
		$post_types[] = 'proofing-gallery';
		
		return $post_types;
	}
	
	add_filter( 'solene_elated_filter_meta_box_post_types_save', 'solene_core_proofing_gallery_meta_box_functions' );
	add_filter( 'solene_elated_filter_meta_box_post_types_remove', 'solene_core_proofing_gallery_meta_box_functions' );
}

if ( ! function_exists( 'solene_core_proofing_gallery_scope_meta_box_functions' ) ) {
	function solene_core_proofing_gallery_scope_meta_box_functions( $post_types ) {
		$post_types[] = 'proofing-gallery';
		
		return $post_types;
	}
	
	add_filter( 'solene_elated_filter_set_scope_for_meta_boxes', 'solene_core_proofing_gallery_scope_meta_box_functions' );
}

if ( ! function_exists( 'solene_core_proofing_gallery_enqueue_meta_box_styles' ) ) {
	function solene_core_proofing_gallery_enqueue_meta_box_styles() {
		global $post;
		
		if ( ! empty( $post ) && $post->post_type == 'proofing-gallery' ) {
			wp_enqueue_style( 'eltdf-jquery-ui', get_template_directory_uri() . '/framework/admin/assets/css/jquery-ui/jquery-ui.css' );
		}
	}
	
	add_action( 'solene_elated_action_enqueue_meta_box_styles', 'solene_core_proofing_gallery_enqueue_meta_box_styles' );
}

if ( ! function_exists( 'solene_core_register_proofing_gallery_cpt' ) ) {
	function solene_core_register_proofing_gallery_cpt( $cpt_class_name ) {
		$cpt_class = array(
			'SoleneCore\CPT\ProofingGallery\ProofingGalleryRegister'
		);
		
		$cpt_class_name = array_merge( $cpt_class_name, $cpt_class );
		
		return $cpt_class_name;
	}
	
	add_filter( 'solene_core_filter_register_custom_post_types', 'solene_core_register_proofing_gallery_cpt' );
}

// Load proofing gallery shortcodes
if ( ! function_exists( 'solene_core_include_proofing_gallery_shortcodes_files' ) ) {
	/**
	 * Loades all shortcodes by going through all folders that are placed directly in shortcodes folder
	 */
	function solene_core_include_proofing_gallery_shortcodes_files() {
		foreach ( glob( SOLENE_CORE_CPT_PATH . '/proofing-gallery/shortcodes/*/load.php' ) as $shortcode_load ) {
			include_once $shortcode_load;
		}
	}
	
	add_action( 'solene_core_action_include_shortcodes_file', 'solene_core_include_proofing_gallery_shortcodes_files' );
}

if ( ! function_exists( 'solene_core_proofing_gallery_get_item_image_size' ) ) {
	/**
	 * Generates proofing-gallery image size
	 *
	 * @param $proportions
	 *
	 * @return string
	 */
	function solene_core_proofing_gallery_get_item_image_size( $proportions = '' ) {
		$thumb_size = 'full';
		
		if ( ! empty( $proportions ) ) {
			
			switch ( $proportions ) {
				case 'landscape':
					$thumb_size = 'solene_core_landscape';
					break;
				case 'portrait':
					$thumb_size = 'solene_core_portrait';
					break;
				case 'square':
					$thumb_size = 'solene_core_square';
					break;
				case 'medium':
					$thumb_size = 'medium';
					break;
				case 'large':
					$thumb_size = 'large';
					break;
				case 'full':
					$thumb_size = 'full';
					break;
				default :
					$thumb_size = 'full';
					break;
			}
		}
		
		return $thumb_size;
	}
}

if ( ! function_exists( 'solene_core_proofing_gallery_item_images_list' ) ) {
	function solene_core_proofing_gallery_item_images_list() {
		$gallery = get_post_meta( get_the_ID(), 'eltdf_proofing_gallery_image_gallery', true );
		
		if ( $gallery !== '' ) {
			return explode( ',', $gallery );
		}
		
		return false;
	}
}

/**
 * Loads more function for proofing-gallery.
 */
if ( ! function_exists( 'solene_core_proofing_gallery_ajax_load_more' ) ) {
	function solene_core_proofing_gallery_ajax_load_more() {
		$shortcode_params = array();
		
		if ( ! empty( $_POST ) ) {
			foreach ( $_POST as $key => $value ) {
				if ( $key !== '' ) {
					$addUnderscoreBeforeCapitalLetter = preg_replace( '/([A-Z])/', '_$1', $key );
					$setAllLettersToLowercase         = strtolower( $addUnderscoreBeforeCapitalLetter );
					
					$shortcode_params[ $setAllLettersToLowercase ] = $value;
				}
			}
		}
		
		$html = '';
		
		$proofing_gallery_list = new \SoleneCore\CPT\Shortcodes\ProofingGallery\ProofingGalleryList();
		
		$query_array                     = $proofing_gallery_list->getQueryArray( $shortcode_params );
		$query_results                   = new \WP_Query( $query_array );
		$shortcode_params['this_object'] = $proofing_gallery_list;
		
		if ( $query_results->have_posts() ):
			while ( $query_results->have_posts() ) : $query_results->the_post();
				$html .= solene_core_get_cpt_shortcode_module_template_part('proofing-gallery', 'proofing-gallery-list', 'proofing-gallery-item', '', $shortcode_params);
			endwhile;
		else:
			$html .= solene_core_get_cpt_shortcode_module_template_part('proofing-gallery', 'proofing-gallery-list', 'parts/posts-not-found');
		endif;
		
		wp_reset_postdata();
		
		$return_obj = array(
			'html' => $html,
		);
		
		echo json_encode( $return_obj );
		exit;
	}
	
	add_action( 'wp_ajax_nopriv_solene_core_proofing_gallery_ajax_load_more', 'solene_core_proofing_gallery_ajax_load_more' );
	add_action( 'wp_ajax_solene_core_proofing_gallery_ajax_load_more', 'solene_core_proofing_gallery_ajax_load_more' );
}

if ( ! function_exists( 'solene_core_get_proofing_gallery_list' ) ) {
	function solene_core_get_proofing_gallery_list() {
		$number_of_items        = 12;
		$number_of_items_option = solene_elated_options()->getOptionValue( 'proofing_gallery_archive_number_of_items' );
		if ( ! empty( $number_of_items_option ) ) {
			$number_of_items = $number_of_items_option;
		}
		
		$number_of_columns        = 'four';
		$number_of_columns_option = solene_elated_options()->getOptionValue( 'proofing_gallery_archive_number_of_columns' );
		if ( ! empty( $number_of_columns_option ) ) {
			$number_of_columns = $number_of_columns_option;
		}
		
		$space_between_items        = 'normal';
		$space_between_items_option = solene_elated_options()->getOptionValue( 'proofing_gallery_archive_space_between_items' );
		if ( ! empty( $space_between_items_option ) ) {
			$space_between_items = $space_between_items_option;
		}
		
		$image_size        = 'landscape';
		$image_size_option = solene_elated_options()->getOptionValue( 'proofing_gallery_archive_image_size' );
		if ( ! empty( $image_size_option ) ) {
			$image_size = $image_size_option;
		}
		
		$params = array(
			'number_of_items'     => $number_of_items,
			'number_of_columns'   => $number_of_columns,
			'space_between_items' => $space_between_items,
			'image_proportions'   => $image_size,
			'pagination_type'     => 'load-more'
		);
		
		$html = solene_elated_execute_shortcode( 'eltdf_proofing_gallery_list', $params );

		echo solene_elated_get_module_part($html);
	}
}

if ( ! function_exists( 'solene_core_single_proofing_gallery' ) ) {
	function solene_core_single_proofing_gallery() {
		$skin              = solene_elated_get_meta_field_intersect( 'proofing_gallery_skin' );
		$number_of_columns = solene_elated_get_meta_field_intersect( 'proofing_gallery_number_of_columns' );
		
		$classes   = array( 'eltdf-proofing-gallery-single-holder' );
		$classes[] = 'eltdf-proofing-gallery-' . $skin;
		
		$params = array(
			'classes'           => implode( ' ', $classes ),
			'number_of_columns' => $number_of_columns
		);
		
		$params['holder_classes'] = ! empty( $number_of_columns ) ? 'eltdf-' . $number_of_columns . '-columns' : 'eltdf-three-columns';
		
		solene_core_get_cpt_single_module_template_part( 'templates/single/holder', 'proofing-gallery', '', $params );
	}
}

if ( ! function_exists( 'solene_core_get_proofing_gallery_single_media' ) ) {
	function solene_core_get_proofing_gallery_single_media() {
		$image_ids = get_post_meta( get_the_ID(), 'eltdf_proofing_gallery_image_gallery', true );
		$gallery   = array();
		
		if ( $image_ids !== '' ) {
			$image_ids = explode( ',', $image_ids );
			
			foreach ( $image_ids as $image_id ) {
				$media              = array();
				$media['title']     = get_the_title( $image_id );
				$media['id']        = $image_id;
				$media['alt']       = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
				$image_src          = wp_get_attachment_image_src( $image_id, 'full' );
				$media['image_url'] = $image_src[0];
				
				$gallery[] = $media;
			}
		}
		
		return $gallery;
	}
}

if ( ! function_exists( 'solene_core_get_proofing_gallery_is_image_approved' ) ) {
	function solene_core_get_proofing_gallery_is_image_approved( $image_id ) {
		$approved_images = get_post_meta( get_the_ID(), 'eltdf_proofing_gallery_images_approved', true );
		$is_approved     = false;
		
		if ( ! empty( $approved_images ) ) {
			
			if ( in_array( $image_id, $approved_images ) ) {
				$is_approved = true;
			}
		}
		
		return $is_approved;
	}
}

if ( ! function_exists( 'solene_core_get_proofing_gallery_image_classes' ) ) {
	function solene_core_get_proofing_gallery_image_classes( $image_id ) {
		$classes = array(
		    'eltdf-pgs-gallery-image',
            'eltdf-item-space'
        );
		
		if ( solene_core_get_proofing_gallery_is_image_approved( $image_id ) ) {
			$classes[] = 'proofing-gallery-image-approved';
		} else {
			$classes[] = 'proofing-gallery-image-rejected';
		}
		
		return implode( ' ', $classes );
	}
}

if ( ! function_exists( 'solene_core_proofing_gallery_approving' ) ) {
	function solene_core_proofing_gallery_approving() {
		$status  = '';
		$message = '';
		$data    = array();
		
		if ( isset( $_POST ) && isset( $_POST['gallery_id'] ) && isset( $_POST['image_id'] ) ) {
			
			$gallery_id = $_POST['gallery_id'];
			$image_id   = $_POST['image_id'];
			
			$approved_images = get_post_meta( $gallery_id, 'eltdf_proofing_gallery_images_approved', true );
			
			if ( ! empty( $approved_images ) ) {
				if ( in_array( $image_id, $approved_images ) ) {
					$approved_images      = array_diff( $approved_images, array( $image_id ) );
					$data['image_status'] = 'rejected';
					$status               = 'success';
					
				} else {
					$approved_images[]    = $image_id;
					$data['image_status'] = 'approved';
					$status               = 'success';
				}
			} else {
				$approved_images      = array( $image_id );
				$data['image_status'] = 'approved';
				$status               = 'success';
			}
			update_post_meta( $gallery_id, 'eltdf_proofing_gallery_images_approved', $approved_images );
		} else {
			$status  = 'error';
			$message = esc_html__( 'Empty params', 'solene-core' );
		}
		
		$response = array(
			'status'  => $status,
			'message' => $message,
			'data'    => $data
		);
		
		$output = json_encode( $response );
		
		exit( $output );
		
		wp_die();
	}
	
	add_action( 'wp_ajax_nopriv_solene_core_proofing_gallery_approving', 'solene_core_proofing_gallery_approving' );
	add_action( 'wp_ajax_solene_core_proofing_gallery_approving', 'solene_core_proofing_gallery_approving' );
}

if ( ! function_exists( 'solene_core_proofing_gallery_password_protected' ) ) {
	function solene_core_proofing_gallery_password_protected( $html ) {
		global $post;
		
		if ( is_singular( 'proofing-gallery' ) ) {
			
			$style = array();
			
			$params['classes'] = array( 'eltdf-password-protected-holder' );
			$params['label']   = 'pwbox-' . ( empty( $post->ID ) ? rand() : $post->ID );
			$full_screen       = solene_elated_get_meta_field_intersect( 'proofing_gallery_password_protected_full_screen' );
			$skin              = solene_elated_get_meta_field_intersect( 'proofing_gallery_password_protected_skin' );
			$bckg_image        = solene_elated_get_meta_field_intersect( 'proofing_gallery_password_protected_background_image' );
			if ( $full_screen == 'yes' ) {
				$params['classes'][] = 'eltdf-password-protected-full-height';
			}
			if ( $skin ) {
				$params['classes'][] = 'eltdf-password-protected-' . $skin;
			}
			if ( $bckg_image ) {
				$style[] = 'background-image:url(' . $bckg_image . ')';
			}
			
			$params['style'] = $style;
			
			$html = solene_core_get_cpt_single_module_template_part( 'templates/single/parts/password-protected', 'proofing-gallery', '', $params );
		}
		
		return $html;
	}
	
	add_filter( 'the_password_form', 'solene_core_proofing_gallery_password_protected' );
}

if ( ! function_exists( 'solene_core_add_proofing_gallery_to_search_types' ) ) {
	function solene_core_add_proofing_gallery_to_search_types( $post_types ) {
		$post_types['proofing-gallery'] = esc_html__( 'Proofing Gallery', 'solene-core' );
		
		return $post_types;
	}
	
	add_filter( 'solene_elated_filter_search_post_type_widget_params_post_type', 'solene_core_add_proofing_gallery_to_search_types' );
}

if ( ! function_exists( 'solene_core_include_proofing_gallery_elementor_widgets_files' ) ) {
    /**
     * Loades all shortcodes by going through all folders that are placed directly in shortcodes folder
     */
    function solene_core_include_proofing_gallery_elementor_widgets_files() {
        if ( solene_core_theme_installed() && solene_elated_is_plugin_installed('elementor') ) {
            foreach (glob(SOLENE_CORE_CPT_PATH . '/proofing-gallery/shortcodes/*/elementor-*.php') as $shortcode_load) {
                include_once $shortcode_load;
            }
        }
    }

    add_action( 'elementor/widgets/widgets_registered', 'solene_core_include_proofing_gallery_elementor_widgets_files' );
}