<?php

namespace SoleneCore\CPT\ProofingGallery;

use SoleneCore\Lib\PostTypeInterface;

/**
 * Class ProofingGalleryRegister
 * @package SoleneCore\CPT\ProofingGallery
 */
class ProofingGalleryRegister implements PostTypeInterface {
	/**
	 * @var string
	 */
	private $base;
	
	public function __construct() {
		$this->base = 'proofing-gallery';
		
		add_filter( 'single_template', array( $this, 'registerSingleTemplate' ) );
	}
	
	/**
	 * @return string
	 */
	public function getBase() {
		return $this->base;
	}
	
	/**
	 * Registers custom post type with WordPress
	 */
	public function register() {
		$this->registerPostType();
	}
	
	/**
	 * Registers proofing-gallery single template if one does'nt exists in theme.
	 * Hooked to single_template filter
	 *
	 * @param $single string current template
	 *
	 * @return string string changed template
	 */
	public function registerSingleTemplate( $single ) {
		global $post;
		
		if ( ! empty( $post ) && $post->post_type == $this->base ) {
			if ( ! file_exists( get_template_directory() . '/single-' . $this->base . '.php' ) ) {
				return SOLENE_CORE_CPT_PATH . '/proofing-gallery/templates/single-' . $this->base . '.php';
			}
		}
		
		return $single;
	}
	
	/**
	 * Registers custom post type with WordPress
	 */
	private function registerPostType() {
		$menuPosition = 5;
		$menuIcon     = 'dashicons-admin-post';
		$slug         = $this->base;
		
		if ( solene_core_theme_installed() ) {
			if ( solene_elated_options()->getOptionValue( 'proofing_gallery_single_slug' ) ) {
				$slug = solene_elated_options()->getOptionValue( 'proofing_gallery_single_slug' );
			}
		}
		
		register_post_type( $this->base,
			array(
				'labels'        => array(
					'name' => esc_html__( 'Solene Proofing Galleries', 'solene-core' ),
					'singular_name' => esc_html__( 'Proofing Gallery Item', 'solene-core' ),
					'add_item' => esc_html__( 'New Proofing Gallery Item', 'solene-core' ),
					'add_new_item' => esc_html__( 'Add New Proofing Gallery Item', 'solene-core' ),
					'edit_item' => esc_html__( 'Edit Proofing Gallery Item', 'solene-core' )
				),
				'public'        => true,
				'has_archive'   => true,
				'rewrite'       => array( 'slug' => $slug ),
				'menu_position' => $menuPosition,
				'show_ui'       => true,
				'supports'      => array(
					'author',
					'title',
					'editor',
					'thumbnail',
					'excerpt',
					'comments',
					'page-attributes'
				),
				'menu_icon'     => $menuIcon
			)
		);
	}
}