<?php
class SoleneCoreElementorProofingGalleryList extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_proofing_gallery_list'; 
	}

	public function get_title() {
		return esc_html__( 'Proofing Gallery List', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-proofing-gallery-list';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'number_of_columns',
			[
				'label'     => esc_html__( 'Number of Columns', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'Default value is Three', 'solene-core' ),
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'one' => esc_html__( 'One', 'solene-core'), 
					'two' => esc_html__( 'Two', 'solene-core'), 
					'three' => esc_html__( 'Three', 'solene-core'), 
					'four' => esc_html__( 'Four', 'solene-core'), 
					'five' => esc_html__( 'Five', 'solene-core'), 
					'six' => esc_html__( 'Six', 'solene-core')
				),
				'default' => 'three'
			]
		);

		$this->add_control(
			'space_between_items',
			[
				'label'     => esc_html__( 'Space Between Items', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'huge' => esc_html__( 'Huge (54)', 'solene-core'), 
					'large' => esc_html__( 'Large (25)', 'solene-core'), 
					'medium' => esc_html__( 'Medium (20)', 'solene-core'), 
					'normal' => esc_html__( 'Normal (15)', 'solene-core'), 
					'small' => esc_html__( 'Small (10)', 'solene-core'), 
					'tiny' => esc_html__( 'Tiny (5)', 'solene-core'), 
					'no' => esc_html__( 'No (0)', 'solene-core')
				),
				'default' => 'normal'
			]
		);

		$this->add_control(
			'number_of_items',
			[
				'label'     => esc_html__( 'Number of Galleries Per Page', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Set number of items for your proofing-gallery list. Enter -1 to show all.', 'solene-core' ),
                'default'   => '-1'
			]
		);

		$this->add_control(
			'image_proportions',
			[
				'label'     => esc_html__( 'Image Proportions', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'Set image proportions for your proofing-gallery list. Also this option will apply to masonry type if you do not set any option in Proofing Gallery Single page for image proportion.', 'solene-core' ),
				'options' => array(
					'full' => esc_html__( 'Original', 'solene-core'), 
					'square' => esc_html__( 'Square', 'solene-core'), 
					'landscape' => esc_html__( 'Landscape', 'solene-core'), 
					'portrait' => esc_html__( 'Portrait', 'solene-core'), 
					'medium' => esc_html__( 'Medium', 'solene-core'), 
					'large' => esc_html__( 'Large', 'solene-core')
				),
				'default' => 'full'
			]
		);

		$this->add_control(
			'selected_projects',
			[
				'label'     => esc_html__( 'Show Only Projects with Listed IDs', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Delimit ID numbers by comma (leave empty for all)', 'solene-core' )
			]
		);

		$this->add_control(
			'orderby',
			[
				'label'     => esc_html__( 'Order By', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'date' => esc_html__( 'Date', 'solene-core'), 
					'ID' => esc_html__( 'ID', 'solene-core'), 
					'menu_order' => esc_html__( 'Menu Order', 'solene-core'), 
					'name' => esc_html__( 'Post Name', 'solene-core'), 
					'rand' => esc_html__( 'Random', 'solene-core'), 
					'title' => esc_html__( 'Title', 'solene-core')
				),
				'default' => 'date'
			]
		);

		$this->add_control(
			'order',
			[
				'label'     => esc_html__( 'Order', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'ASC' => esc_html__( 'ASC', 'solene-core'), 
					'DESC' => esc_html__( 'DESC', 'solene-core')
				),
				'default' => 'ASC'
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'     => esc_html__( 'Title Tag', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'h1' => esc_html__( 'h1', 'solene-core'), 
					'h2' => esc_html__( 'h2', 'solene-core'), 
					'h3' => esc_html__( 'h3', 'solene-core'), 
					'h4' => esc_html__( 'h4', 'solene-core'), 
					'h5' => esc_html__( 'h5', 'solene-core'), 
					'h6' => esc_html__( 'h6', 'solene-core')
				),
				'default' => 'h3'
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'additional_features',
			[
				'label' => esc_html__( 'Additional Features', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'pagination_type',
			[
				'label'     => esc_html__( 'Pagination Type', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'no-pagination' => esc_html__( 'None', 'solene-core'), 
					'standard' => esc_html__( 'Standard', 'solene-core'), 
					'load-more' => esc_html__( 'Load More', 'solene-core'), 
					'infinite-scroll' => esc_html__( 'Infinite Scroll', 'solene-core')
				),
				'default' => 'no-pagination'
			]
		);

		$this->add_control(
			'enable_article_animation',
			[
				'label'     => esc_html__( 'Enable Article Animation', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'Enabling this option you will enable appears animation for your proofing-gallery list items', 'solene-core' ),
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no'
			]
		);


		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();

        $additional_params = array();
		
		$query_array                        = $this->getQueryArray( $params );
		$query_results                      = new \WP_Query( $query_array );
		$additional_params['query_results'] = $query_results;
		
		$additional_params['holder_data']    = solene_elated_get_holder_data_for_cpt( $params, $additional_params );
		$additional_params['holder_classes'] = $this->getHolderClasses( $params );
        $params['title_tag']                 = ! empty( $params['title_tag'] ) ? $params['title_tag'] : 'h3';
		$params['this_object'] = $this;

        echo solene_core_get_cpt_shortcode_module_template_part( 'proofing-gallery', 'proofing-gallery-list', 'proofing-gallery-holder', '', $params, $additional_params );

	}

	public function getQueryArray( $params ) {
		$query_array = array(
			'post_status'    => 'publish',
			'post_type'      => 'proofing-gallery',
			'posts_per_page' => $params['number_of_items'],
			'orderby'        => $params['orderby'],
			'order'          => $params['order']
		);
		
		$project_ids = null;
		if ( ! empty( $params['selected_projects'] ) ) {
			$project_ids             = explode( ',', $params['selected_projects'] );
            $query_array['orderby'] = 'post__in';
			$query_array['post__in'] = $project_ids;
		}
		
		if ( ! empty( $params['next_page'] ) ) {
			$query_array['paged'] = $params['next_page'];
		} else {
			$query_array['paged'] = 1;
		}
		
		return $query_array;
	}

	public function getHolderClasses( $params ) {
		$classes = array( 'eltdf-pgl-gallery', 'eltdf-proofing-gallery-list-holder', 'eltdf-grid-list' );
		
		$classes[] = ! empty( $params['number_of_columns'] ) ? 'eltdf-' . $params['number_of_columns'] . '-columns' : '';
		$classes[] = ! empty( $params['space_between_items'] ) ? 'eltdf-' . $params['space_between_items'] . '-space' : '';
		
		if ( ! empty( $params['pagination_type'] ) ) {
			$classes[] = 'eltdf-pgl-pag-' . $params['pagination_type'];
		}
		
		if ( $params['enable_article_animation'] === 'yes' ) {
			$classes[] = 'eltdf-pgl-has-animation';
		}
		
		return implode( ' ', $classes );
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorProofingGalleryList() );