<?php

namespace SoleneCore\CPT\Shortcodes\ProofingGallery;

use SoleneCore\Lib;

class ProofingGalleryList implements Lib\ShortcodeInterface {
	private $base;

    public function __construct() {
        $this->base = 'eltdf_proofing_gallery_list';

        add_action('vc_before_init', array($this, 'vcMap'));

		//Portfolio selected projects filter
		add_filter( 'vc_autocomplete_eltdf_proofing_gallery_list_selected_projects_callback', array( &$this, 'proofingGalleryIdAutocompleteSuggester', ), 10, 1 ); // Get suggestion(find). Must return an array

		//Portfolio selected projects render
		add_filter( 'vc_autocomplete_eltdf_proofing_gallery_list_selected_projects_render', array( &$this, 'proofingGalleryIdAutocompleteRender', ), 10, 1 ); // Render exact portfolio. Must return an array (label,value)
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map( array(
					'name'                      => esc_html__( 'Proofing Gallery List', 'solene-core' ),
					'base'                      => $this->getBase(),
					'category'                  => esc_html__( 'by SOLENE', 'solene-core' ),
					'icon'                      => 'icon-wpb-proofing-gallery-list extended-custom-icon',
					'allowed_container_element' => 'vc_row',
					'params'                    => array(
						array(
							'type'        => 'dropdown',
							'param_name'  => 'number_of_columns',
							'heading'     => esc_html__( 'Number of Columns', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_number_of_columns_array( true ) ),
							'description' => esc_html__( 'Default value is Three', 'solene-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'space_between_items',
							'heading'     => esc_html__( 'Space Between Items', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_space_between_items_array() ),
							'save_always' => true
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'number_of_items',
							'heading'     => esc_html__( 'Number of Galleries Per Page', 'solene-core' ),
							'description' => esc_html__( 'Set number of items for your proofing-gallery list. Enter -1 to show all.', 'solene-core' ),
							'value'       => '-1'
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'image_proportions',
							'heading'     => esc_html__( 'Image Proportions', 'solene-core' ),
							'value'       => array(
								esc_html__( 'Original', 'solene-core' )  => 'full',
								esc_html__( 'Square', 'solene-core' )    => 'square',
								esc_html__( 'Landscape', 'solene-core' ) => 'landscape',
								esc_html__( 'Portrait', 'solene-core' )  => 'portrait',
								esc_html__( 'Medium', 'solene-core' )    => 'medium',
								esc_html__( 'Large', 'solene-core' )     => 'large'
							),
							'description' => esc_html__( 'Set image proportions for your proofing-gallery list. Also this option will apply to masonry type if you do not set any option in Proofing Gallery Single page for image proportion.', 'solene-core' )
						),
						array(
							'type'        => 'autocomplete',
							'param_name'  => 'selected_projects',
							'heading'     => esc_html__( 'Show Only Projects with Listed IDs', 'solene-core' ),
							'settings'    => array(
								'multiple'      => true,
								'sortable'      => true,
								'unique_values' => true
							),
							'description' => esc_html__( 'Delimit ID numbers by comma (leave empty for all)', 'solene-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'orderby',
							'heading'     => esc_html__( 'Order By', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_query_order_by_array() ),
							'save_always' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'order',
							'heading'     => esc_html__( 'Order', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_query_order_array() ),
							'save_always' => true
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'title_tag',
							'heading'    => esc_html__( 'Title Tag', 'solene-core' ),
							'value'      => array_flip( solene_elated_get_title_tag( true ) )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'pagination_type',
							'heading'    => esc_html__( 'Pagination Type', 'solene-core' ),
							'value'      => array(
								esc_html__( 'None', 'solene-core' )            => 'no-pagination',
								esc_html__( 'Standard', 'solene-core' )        => 'standard',
								esc_html__( 'Load More', 'solene-core' )       => 'load-more',
								esc_html__( 'Infinite Scroll', 'solene-core' ) => 'infinite-scroll'
							),
							'group'      => esc_html__( 'Additional Features', 'solene-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'enable_article_animation',
							'heading'     => esc_html__( 'Enable Article Animation', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_yes_no_select_array( false ) ),
							'description' => esc_html__( 'Enabling this option you will enable appears animation for your proofing-gallery list items', 'solene-core' ),
							'group'       => esc_html__( 'Additional Features', 'solene-core' )
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'number_of_columns'        => 'three',
			'space_between_items'      => 'normal',
			'number_of_items'          => '-1',
			'image_proportions'        => 'full',
			'selected_projects'        => '',
			'orderby'                  => 'date',
			'order'                    => 'ASC',
			'title_tag'                => 'h3',
			'pagination_type'          => 'no-pagination',
			'enable_article_animation' => 'no'
		);
		$params = shortcode_atts( $args, $atts );
		
		$additional_params = array();
		
		$query_array                        = $this->getQueryArray( $params );
		$query_results                      = new \WP_Query( $query_array );
		$additional_params['query_results'] = $query_results;
		
		$additional_params['holder_data']    = solene_elated_get_holder_data_for_cpt( $params, $additional_params );
		$additional_params['holder_classes'] = $this->getHolderClasses( $params, $args );
		
		$params['this_object'] = $this;
		
		$html = solene_core_get_cpt_shortcode_module_template_part( 'proofing-gallery', 'proofing-gallery-list', 'proofing-gallery-holder', '', $params, $additional_params );
		
		return $html;
	}
	
	public function getQueryArray( $params ) {
		$query_array = array(
			'post_status'    => 'publish',
			'post_type'      => 'proofing-gallery',
			'posts_per_page' => $params['number_of_items'],
			'orderby'        => $params['orderby'],
			'order'          => $params['order']
		);
		
		$project_ids = null;
		if ( ! empty( $params['selected_projects'] ) ) {
			$project_ids             = explode( ',', $params['selected_projects'] );
            $query_array['orderby'] = 'post__in';
			$query_array['post__in'] = $project_ids;
		}
		
		if ( ! empty( $params['next_page'] ) ) {
			$query_array['paged'] = $params['next_page'];
		} else {
			$query_array['paged'] = 1;
		}
		
		return $query_array;
	}
	
	public function getHolderClasses( $params, $args ) {
		$classes = array( 'eltdf-pgl-gallery', 'eltdf-proofing-gallery-list-holder', 'eltdf-grid-list' );
		
		$classes[] = ! empty( $params['number_of_columns'] ) ? 'eltdf-' . $params['number_of_columns'] . '-columns' : 'eltdf-' . $args['number_of_columns'] . '-columns';
		$classes[] = ! empty( $params['space_between_items'] ) ? 'eltdf-' . $params['space_between_items'] . '-space' : 'eltdf-' . $args['space_between_items'] . '-space';
		
		if ( ! empty( $params['pagination_type'] ) ) {
			$classes[] = 'eltdf-pgl-pag-' . $params['pagination_type'];
		}
		
		if ( $params['enable_article_animation'] === 'yes' ) {
			$classes[] = 'eltdf-pgl-has-animation';
		}
		
		return implode( ' ', $classes );
	}
	
	/**
	 * Filter portfolios by ID or Title
	 *
	 * @param $query
	 *
	 * @return array
	 */
	public function proofingGalleryIdAutocompleteSuggester( $query ) {
		global $wpdb;
		$portfolio_id = (int) $query;
		$post_meta_infos = $wpdb->get_results( $wpdb->prepare( "SELECT ID AS id, post_title AS title
					FROM {$wpdb->posts}
					WHERE post_type = 'proofing-gallery' AND ( ID = '%d' OR post_title LIKE '%%%s%%' )", $portfolio_id > 0 ? $portfolio_id : - 1, stripslashes( $query ), stripslashes( $query ) ), ARRAY_A );

		$results = array();
		if ( is_array( $post_meta_infos ) && ! empty( $post_meta_infos ) ) {
			foreach ( $post_meta_infos as $value ) {
				$data = array();
				$data['value'] = $value['id'];
				$data['label'] = esc_html__( 'Id', 'solene-core' ) . ': ' . $value['id'] . ( ( strlen( $value['title'] ) > 0 ) ? ' - ' . esc_html__( 'Title', 'solene-core' ) . ': ' . $value['title'] : '' );
				$results[] = $data;
			}
		}

		return $results;
	}

	/**
	 * Find portfolio by id
	 * @since 4.4
	 *
	 * @param $query
	 *
	 * @return bool|array
	 */
	public function proofingGalleryIdAutocompleteRender( $query ) {
		$query = trim( $query['value'] ); // get value from requested
		if ( ! empty( $query ) ) {
			// get portfolio
			$portfolio = get_post( (int) $query );
			if ( ! is_wp_error( $portfolio ) ) {

				$portfolio_id = $portfolio->ID;
				$portfolio_title = $portfolio->post_title;

				$portfolio_title_display = '';
				if ( ! empty( $portfolio_title ) ) {
					$portfolio_title_display = ' - ' . esc_html__( 'Title', 'solene-core' ) . ': ' . $portfolio_title;
				}

				$portfolio_id_display = esc_html__( 'Id', 'solene-core' ) . ': ' . $portfolio_id;

				$data          = array();
				$data['value'] = $portfolio_id;
				$data['label'] = $portfolio_id_display . $portfolio_title_display;

				return ! empty( $data ) ? $data : false;
			}

			return false;
		}

		return false;
	}

}