<?php
class SoleneCoreElementorFrameSlider extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_frame_slider'; 
	}

	public function get_title() {
		return esc_html__( 'Frame Slider', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-frame-slider';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'images',
			[
				'label'     => esc_html__( 'Images', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::GALLERY,
				'description' => esc_html__( 'Select images from media library', 'solene-core' )
			]
		);

		$this->add_control(
			'custom_links',
			[
				'label'     => esc_html__( 'Custom Links', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'Delimit links by comma', 'solene-core' )
			]
		);

		$this->add_control(
			'target',
			[
				'label'     => esc_html__( 'Custom Link Target', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'_self' => esc_html__( 'Same Window', 'solene-core'), 
					'_blank' => esc_html__( 'New Window', 'solene-core')
				),
				'default' => '_self'
			]
		);

		$this->add_control(
			'text',
			[
				'label'     => esc_html__( 'Textual Sticker', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter a word that will be displayed at bottom of frame', 'solene-core' )
			]
		);

		$this->add_control(
			'text_size',
			[
				'label'     => esc_html__( 'Sticker Font Size (px or em)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'text!' => ''
				]
			]
		);

		$this->add_control(
			'text_color',
			[
				'label'     => esc_html__( 'Sticker Color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'condition' => [
					'text!' => ''
				]
			]
		);


		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();

		$params['slider_data']  = $this->getSliderData();
		$params['images']       = $this->getGalleryImages( $params );
		$params['target']       = ! empty( $params['target'] ) ? $params['target'] : '_self';
		$params['links']        = $this->getGalleryLinks( $params );
		$params['text_styles']  = $this->getTextStyles( $params );

        echo solene_core_get_shortcode_module_template_part( 'templates/frame-slider', 'frame-slider', '', $params );

	}

	private function getSliderData() {
		$slider_data = array();
		
		$slider_data['data-number-of-items']   = '4';
		$slider_data['data-slider-margin']     = '0';
		$slider_data['data-enable-center']     = 'yes';
		$slider_data['data-enable-navigation'] = 'no';
		$slider_data['data-enable-pagination'] = 'yes';
		$slider_data['data-enable-autoplay']   = 'yes';

		return $slider_data;
	}

	private function getGalleryImages( $params ) {
		$image_ids = array();
		$images    = array();
		$i         = 0;

        if ( $params['images'] !== '' ) {
            foreach ( $params['images'] as $image ) {
                $image_ids[] = $image['id'];
            }
        }
		
		foreach ( $image_ids as $id ) {
			
			$image['image_id'] = $id;
			$image_original    = wp_get_attachment_image_src( $id, 'full' );
			$image['url']      = $image_original[0];
			$image['alt']      = get_post_meta( $id, '_wp_attachment_image_alt', true );
			
			$images[ $i ] = $image;
			$i ++;
		}
		
		return $images;
	}

	private function getGalleryLinks( $params ) {
		$custom_links = array();
		
		if ( ! empty( $params['custom_links'] ) ) {
			$custom_links = array_map( 'trim', explode( ',', $params['custom_links'] ) );
		}
		
		return $custom_links;
	}

	private function getTextStyles( $params ) {
		$styles = array();
		
		if ( $params['text_size'] !== '' ) {
			$styles[] = 'font-size: ' . $params['text_size'];
		}
		
		if ( ! empty( $params['text_color'] ) ) {
			$styles[] = 'color: ' . $params['text_color'];
		}
		
		return implode( ';', $styles );
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorFrameSlider() );