<?php
class SoleneCoreElementorHorizontalTimeline extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_horizontal_timeline'; 
	}

	public function get_title() {
		return esc_html__( 'Horizontal Timeline', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-horizontal-timeline';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'timeline_format',
			[
				'label'     => esc_html__( 'Timeline displays?', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'Y'         => esc_html__( 'Only Years', 'solene-core'),
					'M Y'       => esc_html__( 'Years and Months', 'solene-core'),
					'M d, \'y'  => esc_html__( 'Years, Months and Days', 'solene-core'),
					'M d'       => esc_html__( 'Months and Days', 'solene-core')
				),
				'default' => 'Y'
			]
		);

		$this->add_control(
			'distance',
			[
				'label'     => esc_html__( 'Minimal Distance Between Dates?', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Default value is 60', 'solene-core' )
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'date',
			[
				'label'     => esc_html__( 'Timeline Date', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter date in format dd/mm/yyyy.', 'solene-core' )
			]
		);

		$repeater->add_control(
			'content_image',
			[
				'label'     => esc_html__( 'Content Image', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA
			]
		);

        solene_core_generate_elementor_templates_control( $repeater );

		$this->add_control(
			'horizontal_timeline_item',
			[
				'label'     => esc_html__( 'SOLENE Horizontal Timeline Item', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::REPEATER,
				'fields'     => $repeater->get_controls(),
				'title_field'     => esc_html__( 'Item', 'solene-core' )
			]
		);


		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();
		$params['timeline_format'] = ! empty( $params['timeline_format'] ) ? $params['timeline_format'] : 'Y';
		$params['dates']           = $this->getDates( $params, $params['timeline_format'] );

        echo solene_core_get_shortcode_module_template_part( 'templates/horizontal-timeline-holder', 'horizontal-timeline', '', $params );

	}

	private function getDates( $params, $timeline_format ) {
        $datesArray = array();

        foreach ( $params['horizontal_timeline_item'] as $item ) {
				if ( ! empty( $item ) ) {
					$date      = new \DateTime( str_replace( '/', '-', $item ) );
					$date_info = getdate( $date->getTimestamp() );

					switch ( $date_info['month'] ) {
						case 'January':
							$month = esc_attr__( 'Jan', 'solene-core' );
							break;
						case 'February':
							$month = esc_attr__( 'Feb', 'solene-core' );
							break;
						case 'March':
							$month = esc_attr__( 'Mar', 'solene-core' );
							break;
						case 'April':
							$month = esc_attr__( 'Apr', 'solene-core' );
							break;
						case 'May':
							$month = esc_attr__( 'May', 'solene-core' );
							break;
						case 'June':
							$month = esc_attr__( 'Jun', 'solene-core' );
							break;
						case 'July':
							$month = esc_attr__( 'Jul', 'solene-core' );
							break;
						case 'August':
							$month = esc_attr__( 'Aug', 'solene-core' );
							break;
						case 'September':
							$month = esc_attr__( 'Sep', 'solene-core' );
							break;
						case 'October':
							$month = esc_attr__( 'Oct', 'solene-core' );
							break;
						case 'November':
							$month = esc_attr__( 'Nov', 'solene-core' );
							break;
						case 'December':
							$month = esc_attr__( 'Dec', 'solene-core' );
							break;
						default:
							$month = $date_info['month'];
							break;
					}
					
					switch ( $timeline_format ) {
						case 'Y':
							$date_label = $date_info['year'];
							break;
						case 'M Y':
							$date_label = $month . ' ' . $date_info['year'];
							break;
						case 'M d, \'y':
							$date_label = $month . ' ' . $date_info['mday'] . ', ' . $date_info['year'];
							break;
						case 'M d':
							$date_label = $month . ' ' . $date_info['mday'];
							break;
						default:
							$date_label = $date_info['year'];
							break;
					}
					
					$currentDate = array(
						'formatted'  => $match,
						'date_label' => $date_label
					);
					
					$datesArray[] = $currentDate;
				}
			}
	
		return $datesArray;
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorHorizontalTimeline() );