(function ($) {
	'use strict';
	
	var interactiveLinkShowcase = {};
	eltdf.modules.interactiveLinkShowcase = interactiveLinkShowcase;
	
	interactiveLinkShowcase.eltdfInitInteractiveLinkShowcase = eltdfInitInteractiveLinkShowcase;
	interactiveLinkShowcase.eltdfOnDocumentReady = eltdfOnDocumentReady;
	
	$(document).ready(eltdfOnDocumentReady);
	$(window).on('load',eltdfOnWindowLoad);

	
	/*
	 All functions to be called on $(document).ready() should be in this function
	 */
	function eltdfOnDocumentReady() {
		eltdfInitInteractiveLinkShowcase();
	}

	/**
	 All functions to be called on $(window).on('load',) should be in this function
	 */
	function eltdfOnWindowLoad() {
		eltdfElementorInteractiveLinkShowcase();
	}

	/**
	 * Elementor
	 */
	function eltdfElementorInteractiveLinkShowcase(){
		$(window).on('elementor/frontend/init', function () {
			elementorFrontend.hooks.addAction( 'frontend/element_ready/eltdf_interactive_link_showcase.default', function() {
				eltdfInitInteractiveLinkShowcase();
			} );
		});
	}


	/**
	 * Init item showcase shortcode
	 */
	function eltdfInitInteractiveLinkShowcase() {
		var holder = $('.eltdf-ils-holder');
		
		if (holder.length) {
			holder.each(function () {
				var thisHolder = $(this),
					singleLink = thisHolder.find('.eltdf-ils-item-link');
				
				if (thisHolder.hasClass('eltdf-ils-standard')) {
					var x = 0,
						y = 0,
						currentXCPosition = 0,
						currentYCPosition = 0;
					
					if (singleLink.length) {
						singleLink.on('mouseenter', function () {
							singleLink.removeClass('eltdf-active');
							$(this).addClass('eltdf-active');
						}).on('mousemove', function (event) {
							var thisItem = $(this),
								followInfoHolder = thisItem.find('.eltdf-ils-follow-content'),
								followImage = followInfoHolder.find('.eltdf-ils-follow-image'),
								followImageItem = followImage.find('img'),
								followImageWidth = followImageItem.width(),
								followImagesCount = parseInt(followImage.data('images-count'), 10),
								followImagesSrc = followImage.data('images'),
								followTitle = followInfoHolder.find('.eltdf-ils-follow-title'),
								itemWidth = thisItem.outerWidth(),
								itemHeight = thisItem.outerHeight(),
								itemOffsetTop = thisItem.offset().top - eltdf.scroll,
								itemOffsetLeft = thisItem.offset().left;
							
							x = (event.clientX - itemOffsetLeft) >> 0;
							y = (event.clientY - itemOffsetTop) >> 0;
							
							if (x > itemWidth) {
								currentXCPosition = itemWidth;
							} else if (x < 0) {
								currentXCPosition = 0;
							} else {
								currentXCPosition = x;
							}
							
							if (y > itemHeight) {
								currentYCPosition = itemHeight;
							} else if (y < 0) {
								currentYCPosition = 0;
							} else {
								currentYCPosition = y;
							}
							
							if (followImagesCount > 1) {
								var imagesUrl = followImagesSrc.split('|'),
									itemPartSize = itemWidth / followImagesCount;
								
								followImageItem.removeAttr('srcset');
								
								if (currentXCPosition < itemPartSize) {
									followImageItem.attr('src', imagesUrl[0]);
								}
								
								// -2 is constant - to remove first and last item from the loop
								for (var index = 1; index <= (followImagesCount - 2); index++) {
									if (currentXCPosition >= itemPartSize * index && currentXCPosition < itemPartSize * (index + 1)) {
										followImageItem.attr('src', imagesUrl[index]);
									}
								}
								
								if (currentXCPosition >= itemWidth - itemPartSize) {
									followImageItem.attr('src', imagesUrl[followImagesCount - 1]);
								}
							}
							
							followImage.css({'top': itemHeight / 2});
							followTitle.css({'transform': 'translateY(' + -(parseInt(itemHeight, 10) / 2 + currentYCPosition) + 'px)', 'left': -(currentXCPosition - followImageWidth/2)});
							followInfoHolder.css({'top': currentYCPosition, 'left': currentXCPosition});
						}).on('mouseleave', function () {
							singleLink.removeClass('eltdf-active');
						});
					}
					
				} else {
					var singleImage = thisHolder.find('.eltdf-ils-item-image'),
						singleLink  = thisHolder.find('.eltdf-ils-item-link');
					
					singleImage.eq(0).addClass('eltdf-active');
					thisHolder.find('.eltdf-ils-item-link[data-index="0"]').addClass('eltdf-active');
					
					singleLink.children().on('touchstart mouseenter', function() {
						var thisLink = $(this).parent(),
							index = parseInt( thisLink.data('index'), 10 );
						
						
						singleImage.removeClass('eltdf-prev');
						singleImage.filter('.eltdf-active').addClass('eltdf-prev');
						singleImage.removeClass('eltdf-active').eq(index).addClass('eltdf-active');
						singleLink.removeClass('eltdf-active');
						thisHolder.find('.eltdf-ils-item-link[data-index="'+index+'"]').addClass('eltdf-active');
					});
				}
			});
		}
	}
	
})(jQuery);