<?php
namespace SoleneCore\CPT\Shortcodes\SectionTitle;

use SoleneCore\Lib;

class SectionTitle implements Lib\ShortcodeInterface {
	private $base;
	
	function __construct() {
		$this->base = 'eltdf_section_title';
		
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                      => esc_html__( 'Section Title', 'solene-core' ),
					'base'                      => $this->base,
					'category'                  => esc_html__( 'by SOLENE', 'solene-core' ),
					'icon'                      => 'icon-wpb-section-title extended-custom-icon',
					'allowed_container_element' => 'vc_row',
					'params'                    => array(
						array(
							'type'        => 'textfield',
							'param_name'  => 'custom_class',
							'heading'     => esc_html__( 'Custom CSS Class', 'solene-core' ),
							'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS', 'solene-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'position',
							'heading'     => esc_html__( 'Horizontal Position', 'solene-core' ),
							'value'       => array(
								esc_html__( 'Default', 'solene-core' ) => '',
								esc_html__( 'Left', 'solene-core' )    => 'left',
								esc_html__( 'Center', 'solene-core' )  => 'center',
								esc_html__( 'Right', 'solene-core' )   => 'right'
							),
							'save_always' => true
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'holder_padding',
							'heading'    => esc_html__( 'Holder Side Padding (px or %)', 'solene-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'separator',
							'heading'     => esc_html__( 'Enable Separator', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_yes_no_select_array( false ) ),
							'save_always' => true
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'separator_height',
							'heading'     => esc_html__( 'Separator Height (px)', 'solene-core' ),
							'dependency'  => array( 'element' => 'separator', 'value' => array( 'yes' ) ),
							'group'       => esc_html__( 'Separator Style', 'solene-core' ),
							'save_always' => true
						),
						array(
							'type'        => 'colorpicker',
							'param_name'  => 'separator_color',
							'heading'     => esc_html__( 'Separator Color', 'solene-core' ),
							'dependency'  => array( 'element' => 'separator', 'value' => array( 'yes' ) ),
							'group'       => esc_html__( 'Separator Style', 'solene-core' ),
							'save_always' => true
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'title',
							'heading'     => esc_html__( 'Title', 'solene-core' ),
							'admin_label' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'title_tag',
							'heading'     => esc_html__( 'Title Tag', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_title_tag( true ) ),
							'save_always' => true,
							'dependency'  => array( 'element' => 'title', 'not_empty' => true ),
							'group'       => esc_html__( 'Title Style', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'title_margin',
							'heading'    => esc_html__( 'Title Top Margin (px)', 'solene-core' ),
							'dependency' => array( 'element' => 'title', 'not_empty' => true ),
							'group'      => esc_html__( 'Title Style', 'solene-core' )
						),
						array(
							'type'       => 'colorpicker',
							'param_name' => 'title_color',
							'heading'    => esc_html__( 'Title Color', 'solene-core' ),
							'dependency' => array( 'element' => 'title', 'not_empty' => true ),
							'group'      => esc_html__( 'Title Style', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'title_link',
							'heading'    => esc_html__( 'Title Link', 'solene-core' ),
							'dependency' => array( 'element' => 'title', 'not_empty' => true ),
							'group'      => esc_html__( 'Title Style', 'solene-core' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'title_link_target',
							'heading'    => esc_html__( 'Title Link Target', 'solene-core' ),
							'value'      => array_flip( solene_elated_get_link_target_array() ),
							'dependency' => array( 'element' => 'title_link', 'not_empty' => true ),
							'group'      => esc_html__( 'Title Style', 'solene-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'title_break_words',
							'heading'     => esc_html__( 'Position of Line Break', 'solene-core' ),
							'description' => esc_html__( 'Enter the position of the word after which you would like to create a line break (e.g. if you would like the line break after the 3rd word, you would enter "3")', 'solene-core' ),
							'dependency'  => array( 'element' => 'title', 'not_empty' => true ),
							'group'       => esc_html__( 'Title Style', 'solene-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'disable_break_words',
							'heading'     => esc_html__( 'Disable Line Break for Smaller Screens', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_yes_no_select_array( false ) ),
							'save_always' => true,
							'dependency'  => array( 'element' => 'title', 'not_empty' => true ),
							'group'       => esc_html__( 'Title Style', 'solene-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'subtitle',
							'heading'     => esc_html__( 'Subtitle', 'solene-core' ),
							'admin_label' => true
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'subtitle_tag',
							'heading'     => esc_html__( 'Subtitle Tag', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_title_tag( true, array( 'p' => 'p' ) ) ),
							'save_always' => true,
							'dependency'  => array( 'element' => 'subtitle', 'not_empty' => true ),
							'group'       => esc_html__( 'Subtitle Style', 'solene-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'subtitle_lineheight',
							'heading'     => esc_html__( 'Subtitle Line Height (px)', 'solene-core' ),
							'save_always' => true,
							'dependency'  => array( 'element' => 'subtitle', 'not_empty' => true ),
							'group'       => esc_html__( 'Subtitle Style', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'subtitle_margin',
							'heading'    => esc_html__( 'Subtitle Top Margin (px)', 'solene-core' ),
							'dependency' => array( 'element' => 'subtitle', 'not_empty' => true ),
							'group'      => esc_html__( 'Subtitle Style', 'solene-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'subtitle_text_transform',
							'heading'     => esc_html__( 'Subtitle Transform', 'solene-core' ),
							'value'      => array_flip( solene_elated_get_text_transform_array( false) ),
							'save_always' => true,
							'dependency'  => array( 'element' => 'subtitle', 'not_empty' => true ),
							'group'       => esc_html__( 'Subtitle Style', 'solene-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'subtitle_style',
							'heading'     => esc_html__( 'Subtitle Style', 'solene-core' ),
							'value'      => array_flip( solene_elated_get_font_style_array( true ) ),
							'save_always' => true,
							'dependency'  => array( 'element' => 'subtitle', 'not_empty' => true ),
							'group'       => esc_html__( 'Subtitle Style', 'solene-core' )
						),
						array(
							'type'        => 'colorpicker',
							'param_name'  => 'subtitle_color',
							'heading'     => esc_html__( 'Subtitle Color', 'solene-core' ),
							'admin_label' => true,
							'dependency'  => array( 'element' => 'subtitle', 'not_empty' => true ),
							'group'       => esc_html__( 'Subtitle Style', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'subtitle_link',
							'heading'    => esc_html__( 'Subtitle Link', 'solene-core' ),
							'dependency' => array( 'element' => 'subtitle', 'not_empty' => true ),
							'group'      => esc_html__( 'Subtitle Style', 'solene-core' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'subtitle_link_target',
							'heading'    => esc_html__( 'Subtitle Link Target', 'solene-core' ),
							'value'      => array_flip( solene_elated_get_link_target_array() ),
							'dependency' => array( 'element' => 'subtitle_link', 'not_empty' => true ),
							'group'      => esc_html__( 'Subtitle Style', 'solene-core' )
						),
						array(
							'type'       => 'textarea',
							'param_name' => 'text',
							'heading'    => esc_html__( 'Text', 'solene-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'text_tag',
							'heading'     => esc_html__( 'Text Tag', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_title_tag( true, array( 'p' => 'p' ) ) ),
							'save_always' => true,
							'dependency'  => array( 'element' => 'text', 'not_empty' => true ),
							'group'       => esc_html__( 'Text Style', 'solene-core' )
						),
						array(
							'type'       => 'colorpicker',
							'param_name' => 'text_color',
							'heading'    => esc_html__( 'Text Color', 'solene-core' ),
							'dependency' => array( 'element' => 'text', 'not_empty' => true ),
							'group'      => esc_html__( 'Text Style', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'text_font_size',
							'heading'    => esc_html__( 'Text Font Size (px)', 'solene-core' ),
							'dependency' => array( 'element' => 'text', 'not_empty' => true ),
							'group'      => esc_html__( 'Text Style', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'text_line_height',
							'heading'    => esc_html__( 'Text Line Height (px)', 'solene-core' ),
							'dependency' => array( 'element' => 'text', 'not_empty' => true ),
							'group'      => esc_html__( 'Text Style', 'solene-core' )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'text_font_weight',
							'heading'     => esc_html__( 'Text Font Weight', 'solene-core' ),
							'value'       => array_flip( solene_elated_get_font_weight_array( true ) ),
							'save_always' => true,
							'dependency'  => array( 'element' => 'text', 'not_empty' => true ),
							'group'       => esc_html__( 'Text Style', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'text_margin',
							'heading'    => esc_html__( 'Text Top Margin (px)', 'solene-core' ),
							'dependency' => array( 'element' => 'text', 'not_empty' => true ),
							'group'      => esc_html__( 'Text Style', 'solene-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'button_text',
							'heading'     => esc_html__( 'Button Text', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'button_link',
							'heading'    => esc_html__( 'Button Link', 'solene-core' ),
							'group'      => esc_html__( 'Button Style', 'solene-core' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'button_target',
							'heading'    => esc_html__( 'Button Link Target', 'solene-core' ),
							'value'      => array_flip( solene_elated_get_link_target_array() ),
							'group'      => esc_html__( 'Button Style', 'solene-core' )
						),
						array(
							'type'       => 'colorpicker',
							'param_name' => 'button_color',
							'heading'    => esc_html__( 'Button Color', 'solene-core' ),
							'group'      => esc_html__( 'Button Style', 'solene-core' )
						),
						array(
							'type'       => 'colorpicker',
							'param_name' => 'button_hover_color',
							'heading'    => esc_html__( 'Button Hover Color', 'solene-core' ),
							'group'      => esc_html__( 'Button Style', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'button_top_margin',
							'heading'    => esc_html__( 'Button Top Margin (px)', 'solene-core' ),
							'group'      => esc_html__( 'Button Style', 'solene-core' )
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'custom_class'            => '',
			'position'                => '',
			'holder_padding'          => '',
			'separator'               => '',
			'separator_height'        => '',
			'separator_color'         => '',
			'title'                   => '',
			'title_tag'               => 'h2',
			'title_margin'            => '',
			'title_color'             => '',
			'title_link'              => '',
			'title_link_target'       => '_self',
			'title_break_words'       => '',
			'disable_break_words'     => '',
			'subtitle'                => '',
			'subtitle_tag'            => 'h3',
			'subtitle_lineheight'     => '',
			'subtitle_margin'         => '',
			'subtitle_text_transform' => 'none',
			'subtitle_style'          => '',
			'subtitle_color'          => '',
			'subtitle_link'           => '',
			'subtitle_link_target'    => '_self',
			'text'                    => '',
			'text_tag'                => 'p',
			'text_color'              => '',
			'text_font_size'          => '',
			'text_line_height'        => '',
			'text_font_weight'        => '',
			'text_margin'             => '',
			'button_text'             => '',
			'button_link'             => '',
			'button_target'           => '_self',
			'button_color'            => '',
			'button_hover_color'      => '',
			'button_top_margin'       => ''
		);
		$params = shortcode_atts( $args, $atts );
		
		$params['holder_classes']    = $this->getHolderClasses( $params, $args );
		$params['holder_styles']     = $this->getHolderStyles( $params );
		$params['separator_styles']  = $this->getSeparatrorStyles( $params );
		$params['title']             = $this->getModifiedTitle( $params );
		$params['title_tag']         = ! empty( $params['title_tag'] ) ? $params['title_tag'] : $args['title_tag'];
		$params['title_styles']      = $this->getTitleStyles( $params );
		$params['subtitle_tag']      = ! empty( $params['subtitle_tag'] ) ? $params['subtitle_tag'] : $args['subtitle_tag'];
		$params['subtitle_styles']   = $this->getSubtitleStyles( $params );
		$params['text_tag']          = ! empty( $params['text_tag'] ) ? $params['text_tag'] : $args['text_tag'];
		$params['text_styles']       = $this->getTextStyles( $params );
		$params['button_parameters'] = $this->getButtonParameters( $params );
		
		$html = solene_core_get_shortcode_module_template_part( 'templates/section-title', 'section-title', '', $params );
		
		return $html;
	}
	
	private function getHolderClasses( $params, $args ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['custom_class'] ) ? esc_attr( $params['custom_class'] ) : '';
		$holderClasses[] = $params['disable_break_words'] === 'yes' ? 'eltdf-st-disable-title-break' : '';
		
		return implode( ' ', $holderClasses );
	}
	
	private function getHolderStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['holder_padding'] ) ) {
			$styles[] = 'padding: 0 ' . $params['holder_padding'];
		}
		
		if ( ! empty( $params['position'] ) ) {
			$styles[] = 'text-align: ' . $params['position'];
		}
		
		return implode( ';', $styles );
	}
	
	private function getModifiedTitle( $params ) {
		$title             = $params['title'];
		$title_break_words = str_replace( ' ', '', $params['title_break_words'] );
		
		if ( ! empty( $title ) && ! empty( $title_break_words ) ) {
			$split_title = explode( ' ', $title );
			
			if ( ! empty( $title_break_words ) ) {
				$break_words = explode( ',', $title_break_words );
				
				foreach ( $break_words as $value ) {
					if ( ! empty( $split_title[ $value - 1 ] ) ) {
						$split_title[ $value - 1 ] = $split_title[ $value - 1 ] . '<br />';
					}
				}
			}
			
			$title = implode( ' ', $split_title );
		}
		
		return $title;
	}
	
	private function getSeparatrorStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['separator_color'] ) ) {
			$styles[] = 'color: ' . $params['separator_color'];
		}
		
		if ( ! empty( $params['separator_height'] ) ) {
			$styles[] = 'height: ' . solene_elated_filter_px( $params['separator_height'] ) . 'px';
		}
		
		return implode( ';', $styles );
	}
	
	private function getTitleStyles( $params ) {
		$styles = array();
		
		if ( $params['title_margin'] !== '' ) {
			$styles[] = 'margin-top: ' . solene_elated_filter_px( $params['title_margin'] ) . 'px';
		}
		
		if ( ! empty( $params['title_color'] ) ) {
			$styles[] = 'color: ' . $params['title_color'];
		}
		
		return implode( ';', $styles );
	}
	
	private function getSubtitleStyles( $params ) {
		$styles = array();
		
		if ( $params['subtitle_lineheight'] !== '' ) {
			$styles[] = 'line-height: ' . solene_elated_filter_px( $params['subtitle_lineheight'] ) . 'px';
		}
		
		if ( $params['subtitle_margin'] !== '' ) {
			$styles[] = 'margin-top: ' . solene_elated_filter_px( $params['subtitle_margin'] ) . 'px';
		}
		
		if ( ! empty( $params['subtitle_text_transform'] ) ) {
			$styles[] = 'text-transform: ' . $params['subtitle_text_transform'];
		}
		
		if ( ! empty( $params['subtitle_style'] ) ) {
			$styles[] = 'font-style: ' . $params['subtitle_style'];
		}
		
		if ( ! empty( $params['subtitle_color'] ) ) {
			$styles[] = 'color: ' . $params['subtitle_color'];
		}
		
		return implode( ';', $styles );
	}
	
	private function getTextStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['text_color'] ) ) {
			$styles[] = 'color: ' . $params['text_color'];
		}
		
		if ( ! empty( $params['text_font_size'] ) ) {
			$styles[] = 'font-size: ' . solene_elated_filter_px( $params['text_font_size'] ) . 'px';
		}
		
		if ( ! empty( $params['text_line_height'] ) ) {
			$styles[] = 'line-height: ' . solene_elated_filter_px( $params['text_line_height'] ) . 'px';
		}
		
		if ( ! empty( $params['text_font_weight'] ) ) {
			$styles[] = 'font-weight: ' . $params['text_font_weight'];
		}
		
		if ( $params['text_margin'] !== '' ) {
			$styles[] = 'margin-top: ' . solene_elated_filter_px( $params['text_margin'] ) . 'px';
		}
		
		return implode( ';', $styles );
	}
	
	private function getButtonParameters( $params ) {
		$button_params = array();
		
		if ( ! empty( $params['button_text'] ) ) {
			$button_params['text'] = $params['button_text'];
			$button_params['type'] = 'solid';
			$button_params['link'] = ! empty( $params['button_link'] ) ? $params['button_link'] : '#';
			$button_params['target'] = ! empty( $params['button_target'] ) ? $params['button_target'] : '_self';
			
			if ( ! empty( $params['button_color'] ) ) {
				$button_params['color'] = $params['button_color'];
			}
			
			if ( ! empty( $params['button_hover_color'] ) ) {
				$button_params['hover_color'] = $params['button_hover_color'];
			}
			
			if ( $params['button_top_margin'] !== '' ) {
				$button_params['margin'] = intval( $params['button_top_margin'] ) . 'px 0 0';
			}
		}
		
		return $button_params;
	}
}