<?php
class SoleneCoreElementorStamp extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_stamp'; 
	}

	public function get_title() {
		return esc_html__( 'Stamp', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-stamp';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'custom_class',
			[
				'label'     => esc_html__( 'Custom CSS Class', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS', 'solene-core' )
			]
		);

		$this->add_control(
			'text',
			[
				'label'     => esc_html__( 'Stamp Text', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'image',
			[
				'label'     => esc_html__( 'Stamp Image', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA
			]
		);

		$this->add_control(
			'link',
			[
				'label'     => esc_html__( 'Custom Link', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'text_color',
			[
				'label'     => esc_html__( 'Text Color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'condition' => [
					'text!' => ''
				]
			]
		);

		$this->add_control(
			'text_font_size',
			[
				'label'     => esc_html__( 'Text Font Size (px)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'text!' => ''
				]
			]
		);

		$this->add_control(
			'stamp_size',
			[
				'label'     => esc_html__( 'Stamp Size (px)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Default value is 123', 'solene-core' ),
				'condition' => [
					'text!' => ''
				]
			]
		);

		$this->add_control(
			'enable_repeating_animation',
			[
				'label'     => esc_html__( 'Enable Repeating Animation', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes',
				'condition' => [
					'text!' => ''
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'visibility',
			[
				'label' => esc_html__( 'Visibility', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'disable_stamp',
			[
				'label'     => esc_html__( 'Disable Stamp', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'Choose on which stage you will hide stamp shortcode', 'solene-core' ),
				'options' => array(
					'' => esc_html__( 'Never', 'solene-core'), 
					'1440' => esc_html__( 'Below 1440px', 'solene-core'), 
					'1280' => esc_html__( 'Below 1280px', 'solene-core'), 
					'1024' => esc_html__( 'Below 1024px', 'solene-core'), 
					'768' => esc_html__( 'Below 768px', 'solene-core'), 
					'680' => esc_html__( 'Below 680px', 'solene-core'), 
					'480' => esc_html__( 'Below 480px', 'solene-core')
				),
				'default' => '',
				'condition' => [
					'text!' => ''
				]
			]
		);

		$this->add_control(
			'appearing_delay',
			[
				'label'     => esc_html__( 'Appearing Delay (ms)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Default value is 0', 'solene-core' ),
				'condition' => [
					'text!' => ''
				]
			]
		);

		$this->add_control(
			'absolute_position',
			[
				'label'     => esc_html__( 'Enable Absolute Position', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'no' => esc_html__( 'No', 'solene-core'), 
					'yes' => esc_html__( 'Yes', 'solene-core')
				),
				'default' => 'no',
				'condition' => [
					'text!' => ''
				]
			]
		);

		$this->add_control(
			'top_position',
			[
				'label'     => esc_html__( 'Top Position (px or %)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'absolute_position' => array( 'yes' )
				]
			]
		);

		$this->add_control(
			'left_position',
			[
				'label'     => esc_html__( 'Left Position (px or %)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'absolute_position' => array( 'yes' )
				]
			]
		);

		$this->add_control(
			'right_position',
			[
				'label'     => esc_html__( 'Right Position (px or %)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'absolute_position' => array( 'yes' )
				]
			]
		);

		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();
        $params['image'] = !empty($params['image']) ? $params['image']['id'] : $params['image'];
		$params['holder_classes'] = $this->getHolderClasses( $params );
		$params['holder_styles']  = $this->getHolderStyles( $params );
		$params['holder_data']    = $this->getHolderData( $params );
		$params['text_data']      = $this->getModifiedText( $params );

        echo solene_core_get_shortcode_module_template_part( 'templates/stamp', 'stamp', '', $params );

	}

	private function getHolderClasses( $params ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['custom_class'] ) ? esc_attr( $params['custom_class'] ) : '';
		$holderClasses[] = $params['enable_repeating_animation'] === 'yes' ? 'eltdf-repeating' : '';
		$holderClasses[] = ! empty( $params['disable_stamp'] ) ? 'eltdf-hide-on-' . esc_attr( $params['disable_stamp'] ) : '';
		$holderClasses[] = $params['absolute_position'] === 'yes' ? 'eltdf-abs' : '';
		
		return implode( ' ', $holderClasses );
	}

	private function getHolderStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['text_color'] ) ) {
			$styles[] = 'color: ' . $params['text_color'];
		}
		
		if ( ! empty( $params['text_font_size'] ) ) {
			$styles[] = 'font-size: ' . solene_elated_filter_px( $params['text_font_size'] ) . 'px';
		}
		
		if ( ! empty( $params['stamp_size'] ) ) {
			$styles[] = 'width: ' . solene_elated_filter_px( $params['stamp_size'] ) . 'px';
			$styles[] = 'height: ' . solene_elated_filter_px( $params['stamp_size'] ) . 'px';
		}
		
		if ( $params['top_position'] !== '' ) {
			$styles[] = 'top: ' . $params['top_position'];
		}
		
		if ( $params['left_position'] !== '' ) {
			$styles[] = 'left: ' . $params['left_position'];
		}
		
		if ( $params['right_position'] !== '' ) {
			$styles[] = 'right: ' . $params['right_position'];
		}
		
		return implode( ';', $styles );
	}

	private function getHolderData( $params ) {
		$slider_data = array();
		
		$slider_data['data-appearing-delay'] = ! empty( $params['appearing_delay'] ) ? intval( $params['appearing_delay'] ) : 0;
		
		return $slider_data;
	}

	private function getModifiedText( $params ) {
		$text = $params['text'];
		$data = array(
			'text'  => solene_elated_get_split_text( $text ),
			'count' => count( solene_elated_str_split_unicode( $text ) ) + 1
		);
		
		return $data;
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorStamp() );