<?php
namespace SoleneCore\CPT\Shortcodes\Stamp;

use SoleneCore\Lib;

class Stamp implements Lib\ShortcodeInterface {
	private $base;
	
	public function __construct() {
		$this->base = 'eltdf_stamp';
		
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                      => esc_html__( 'Stamp', 'solene-core' ),
					'base'                      => $this->getBase(),
					'category'                  => esc_html__( 'by SOLENE', 'solene-core' ),
					'icon'                      => 'icon-wpb-stamp extended-custom-icon',
					'allowed_container_element' => 'vc_row',
					'params'                    => array(
						array(
							'type'        => 'textfield',
							'param_name'  => 'custom_class',
							'heading'     => esc_html__( 'Custom CSS Class', 'solene-core' ),
							'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'text',
							'heading'    => esc_html__( 'Stamp Text', 'solene-core' )
						),
						array(
							'type'       => 'attach_image',
							'param_name' => 'image',
							'heading'    => esc_html__( 'Stamp Image', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'link',
							'heading'    => esc_html__( 'Custom Link', 'solene-core' )
						),
						array(
							'type'       => 'colorpicker',
							'param_name' => 'text_color',
							'heading'    => esc_html__( 'Text Color', 'solene-core' ),
							'dependency' => array( 'element' => 'text', 'not_empty' => true )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'text_font_size',
							'heading'    => esc_html__( 'Text Font Size (px)', 'solene-core' ),
							'dependency' => array( 'element' => 'text', 'not_empty' => true )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'stamp_size',
							'heading'     => esc_html__( 'Stamp Size (px)', 'solene-core' ),
							'description' => esc_html__( 'Default value is 123', 'solene-core' ),
							'dependency'  => array( 'element' => 'text', 'not_empty' => true )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'enable_repeating_animation',
							'heading'    => esc_html__( 'Enable Repeating Animation', 'solene-core' ),
							'value'      => array_flip( solene_elated_get_yes_no_select_array( false, true ) ),
							'dependency' => array( 'element' => 'text', 'not_empty' => true )
						),
						array(
							'type'        => 'dropdown',
							'param_name'  => 'disable_stamp',
							'heading'     => esc_html__( 'Disable Stamp', 'solene-core' ),
							'description' => esc_html__( 'Choose on which stage you will hide stamp shortcode', 'solene-core' ),
							'value'       => array(
								esc_html__( 'Never', 'solene-core' )        => '',
								esc_html__( 'Below 1440px', 'solene-core' ) => '1440',
								esc_html__( 'Below 1280px', 'solene-core' ) => '1280',
								esc_html__( 'Below 1024px', 'solene-core' ) => '1024',
								esc_html__( 'Below 768px', 'solene-core' )  => '768',
								esc_html__( 'Below 680px', 'solene-core' )  => '680',
								esc_html__( 'Below 480px', 'solene-core' )  => '480'
							),
							'dependency'  => array( 'element' => 'text', 'not_empty' => true ),
							'group'       => esc_html__( 'Visibility', 'solene-core' )
						),
						array(
							'type'        => 'textfield',
							'param_name'  => 'appearing_delay',
							'heading'     => esc_html__( 'Appearing Delay (ms)', 'solene-core' ),
							'description' => esc_html__( 'Default value is 0', 'solene-core' ),
							'dependency'  => array( 'element' => 'text', 'not_empty' => true ),
							'group'       => esc_html__( 'Visibility', 'solene-core' )
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'absolute_position',
							'heading'    => esc_html__( 'Enable Absolute Position', 'solene-core' ),
							'value'      => array_flip( solene_elated_get_yes_no_select_array( false ) ),
							'dependency' => array( 'element' => 'text', 'not_empty' => true ),
							'group'      => esc_html__( 'Visibility', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'top_position',
							'heading'    => esc_html__( 'Top Position (px or %)', 'solene-core' ),
							'dependency' => array( 'element' => 'absolute_position', 'value' => array( 'yes' ) ),
							'group'      => esc_html__( 'Visibility', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'left_position',
							'heading'    => esc_html__( 'Left Position (px or %)', 'solene-core' ),
							'dependency' => array( 'element' => 'absolute_position', 'value' => array( 'yes' ) ),
							'group'      => esc_html__( 'Visibility', 'solene-core' )
						),
						array(
							'type'       => 'textfield',
							'param_name' => 'right_position',
							'heading'    => esc_html__( 'Right Position (px or %)', 'solene-core' ),
							'dependency' => array( 'element' => 'absolute_position', 'value' => array( 'yes' ) ),
							'group'      => esc_html__( 'Visibility', 'solene-core' )
						)
					)
				)
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'custom_class'               => '',
			'image'                      => '',
			'text'                       => '',
			'link'                       => '',
			'text_color'                 => '',
			'text_font_size'             => '',
			'stamp_size'                 => '',
			'enable_repeating_animation' => 'yes',
			'disable_stamp'              => '',
			'appearing_delay'            => '0',
			'absolute_position'          => 'no',
			'top_position'               => '',
			'left_position'              => '',
			'right_position'             => ''
		);
		$params = shortcode_atts( $args, $atts );
		
		$params['holder_classes'] = $this->getHolderClasses( $params );
		$params['holder_styles']  = $this->getHolderStyles( $params );
		$params['holder_data']    = $this->getHolderData( $params );
		$params['text_data']      = $this->getModifiedText( $params );
		
		$html = solene_core_get_shortcode_module_template_part( 'templates/stamp', 'stamp', '', $params );
		
		return $html;
	}
	
	private function getHolderClasses( $params ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['custom_class'] ) ? esc_attr( $params['custom_class'] ) : '';
		$holderClasses[] = $params['enable_repeating_animation'] === 'yes' ? 'eltdf-repeating' : '';
		$holderClasses[] = ! empty( $params['disable_stamp'] ) ? 'eltdf-hide-on-' . esc_attr( $params['disable_stamp'] ) : '';
		$holderClasses[] = $params['absolute_position'] === 'yes' ? 'eltdf-abs' : '';
		
		return implode( ' ', $holderClasses );
	}
	
	private function getHolderStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['text_color'] ) ) {
			$styles[] = 'color: ' . $params['text_color'];
		}
		
		if ( ! empty( $params['text_font_size'] ) ) {
			$styles[] = 'font-size: ' . solene_elated_filter_px( $params['text_font_size'] ) . 'px';
		}
		
		if ( ! empty( $params['stamp_size'] ) ) {
			$styles[] = 'width: ' . solene_elated_filter_px( $params['stamp_size'] ) . 'px';
			$styles[] = 'height: ' . solene_elated_filter_px( $params['stamp_size'] ) . 'px';
		}
		
		if ( $params['top_position'] !== '' ) {
			$styles[] = 'top: ' . $params['top_position'];
		}
		
		if ( $params['left_position'] !== '' ) {
			$styles[] = 'left: ' . $params['left_position'];
		}
		
		if ( $params['right_position'] !== '' ) {
			$styles[] = 'right: ' . $params['right_position'];
		}
		
		return implode( ';', $styles );
	}
	
	private function getHolderData( $params ) {
		$slider_data = array();
		
		$slider_data['data-appearing-delay'] = ! empty( $params['appearing_delay'] ) ? intval( $params['appearing_delay'] ) : 0;
		
		return $slider_data;
	}
	
	private function getModifiedText( $params ) {
		$text = $params['text'];
		$data = array(
			'text'  => solene_elated_get_split_text( $text ),
			'count' => count( solene_elated_str_split_unicode( $text ) ) + 1
		);
		
		return $data;
	}
}