<?php
class SoleneCoreElementorSwappingImageGallery extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_swapping_image_gallery'; 
	}

	public function get_title() {
		return esc_html__( 'Swapping Image Gallery', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-swapping-image-gallery';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'title',
			[
				'label'     => esc_html__( 'Title', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'title_highlight_words',
			[
				'label'     => esc_html__( 'Highlight Words', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter the positions of the words you would like to display in a most dominant color of your theme. Separate the positions with commas (e.g. if you would like the first, second, and third word to have a desired color, you would enter &quot;1,2,3&quot;)', 'solene-core' ),
				'condition' => [
					'title!' => ''
				]
			]
		);

		$this->add_control(
			'title_break_words',
			[
				'label'     => esc_html__( 'Position of Line Break', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter the position of the word after which you would like to create a line break (e.g. if you would like the line break after the 3rd word, you would enter &quot;3&quot;)', 'solene-core' ),
				'condition' => [
					'title!' => ''
				]
			]
		);

		$this->add_control(
			'description',
			[
				'label'     => esc_html__( 'Description', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'gallery_image',
			[
				'label'     => esc_html__( 'Main Image', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA,
				'description' => esc_html__( 'Select image from media library', 'solene-core' )
			]
		);

		$repeater->add_control(
			'gallery_image_link',
			[
				'label'     => esc_html__( 'Main Image Link', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$repeater->add_control(
			'thumbnail',
			[
				'label'     => esc_html__( 'Thumbnail', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA,
				'description' => esc_html__( 'Select image from media library', 'solene-core' )
			]
		);

		$this->add_control(
			'image_items',
			[
				'label'     => esc_html__( 'Image Items', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::REPEATER,
				'fields'     => $repeater->get_controls(),
				'title_field'     => esc_html__( 'Item', 'solene-core' )
			]
		);


		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();

		$params['slider_data']	= $this->getSliderData( $params );

		for($i=0; $i<=count($params['image_items']); $i++){

		    if(!empty($params['image_items'][$i]['gallery_image'])){
                $params['image_items'][$i]['gallery_image'] = $params['image_items'][$i]['gallery_image']['id'];
            }
		    if(!empty($params['image_items'][$i]['thumbnail'])){
                $params['image_items'][$i]['thumbnail'] = $params['image_items'][$i]['thumbnail']['id'];
            }
        }

		$params['title']        = $this->getModifiedTitle( $params );

        echo solene_core_get_shortcode_module_template_part( 'templates/swapping-image-gallery', 'swapping-image-gallery', '', $params );

	}

	private function getModifiedTitle( $params ) {
		$title             = $params['title'];
		$title_highlight_words  = str_replace( ' ', '', $params['title_highlight_words'] );
		$title_break_words = str_replace( ' ', '', $params['title_break_words'] );

		if ( ! empty( $title ) ) {
			$highlight_words  = explode( ',', $title_highlight_words );
			$split_title = explode( ' ', $title );

			if ( ! empty( $title_highlight_words ) ) {
				foreach ( $highlight_words as $value ) {
					if ( ! empty( $split_title[ $value - 1 ] ) ) {
						$split_title[ $value - 1 ] = '<span class="eltdf-st-title-highlight">' . $split_title[ $value - 1 ] . '</span>';
					}
				}
			}

			if ( ! empty( $title_break_words ) ) {
				if ( ! empty( $split_title[ $title_break_words - 1 ] ) ) {
					$split_title[ $title_break_words - 1 ] = $split_title[ $title_break_words - 1 ] . '<br />';
				}
			}

			$title = implode( ' ', $split_title );
		}

		return $title;
	}

	private function getSliderData( $params ) {
		$slider_data = array();
		
		$slider_data['data-slider-animate-in'] 	= 'fadeIn';
		
		return $slider_data;
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorSwappingImageGallery() );