<?php
class SoleneCoreElementorTeamCarousel extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_team_carousel'; 
	}

	public function get_title() {
		return esc_html__( 'Team Carousel', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-team-carousel';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'number_of_visible_items',
			[
				'label'     => esc_html__( 'Number of Visible Items', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'1' => esc_html__( 'One', 'solene-core'), 
					'2' => esc_html__( 'Two', 'solene-core'), 
					'3' => esc_html__( 'Three', 'solene-core'), 
					'4' => esc_html__( 'Four', 'solene-core'), 
					'5' => esc_html__( 'Five', 'solene-core'), 
					'6' => esc_html__( 'Six', 'solene-core')
				),
				'default' => '3'
			]
		);

		$this->add_control(
			'space_between_items',
			[
				'label'     => esc_html__( 'Space Between Items', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'huge' => esc_html__( 'Huge (54)', 'solene-core'), 
					'large' => esc_html__( 'Large (25)', 'solene-core'), 
					'medium' => esc_html__( 'Medium (20)', 'solene-core'), 
					'normal' => esc_html__( 'Normal (15)', 'solene-core'), 
					'small' => esc_html__( 'Small (10)', 'solene-core'), 
					'tiny' => esc_html__( 'Tiny (5)', 'solene-core'), 
					'no' => esc_html__( 'No (0)', 'solene-core')
				),
				'default' => 'normal'
			]
		);

		$this->add_control(
			'slider_loop',
			[
				'label'     => esc_html__( 'Enable Slider Loop', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$this->add_control(
			'slider_autoplay',
			[
				'label'     => esc_html__( 'Enable Slider Autoplay', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$this->add_control(
			'slider_speed',
			[
				'label'     => esc_html__( 'Slide Duration', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Default value is 5000 (ms)', 'solene-core' )
			]
		);

		$this->add_control(
			'slider_speed_animation',
			[
				'label'     => esc_html__( 'Slide Animation Duration', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Speed of slide animation in milliseconds. Default value is 600.', 'solene-core' )
			]
		);

		$this->add_control(
			'slider_navigation',
			[
				'label'     => esc_html__( 'Enable Slider Navigation Arrows', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$this->add_control(
			'slider_pagination',
			[
				'label'     => esc_html__( 'Enable Slider Pagination', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'type',
			[
				'label'     => esc_html__( 'Type', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'info-below-image' => esc_html__( 'Info Below Image', 'solene-core'), 
					'info-on-image' => esc_html__( 'Info On Image Hover', 'solene-core')
				),
				'default' => 'info-below-image'
			]
		);

		$repeater->add_control(
			'top_offset',
			[
				'label'     => esc_html__( 'Top Offset (px)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'type' => array( 'info-below-image' )
				]
			]
		);

		$repeater->add_control(
			'team_image',
			[
				'label'     => esc_html__( 'Image', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA
			]
		);

		$repeater->add_control(
			'team_hover_image',
			[
				'label'     => esc_html__( 'Hover Image', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'type' => array( 'info-below-image' )
				]
			]
		);

		$repeater->add_control(
			'team_name',
			[
				'label'     => esc_html__( 'Name', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$repeater->add_control(
			'team_name_tag',
			[
				'label'     => esc_html__( 'Name Tag', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'h1' => esc_html__( 'h1', 'solene-core'), 
					'h2' => esc_html__( 'h2', 'solene-core'), 
					'h3' => esc_html__( 'h3', 'solene-core'), 
					'h4' => esc_html__( 'h4', 'solene-core'), 
					'h5' => esc_html__( 'h5', 'solene-core'), 
					'h6' => esc_html__( 'h6', 'solene-core')
				),
				'default' => 'h3',
				'condition' => [
					'team_name!' => ''
				]
			]
		);

		$repeater->add_control(
			'team_name_color',
			[
				'label'     => esc_html__( 'Name Color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'condition' => [
					'team_name!' => ''
				]
			]
		);

		$repeater->add_control(
			'team_position',
			[
				'label'     => esc_html__( 'Position', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$repeater->add_control(
			'team_position_color',
			[
				'label'     => esc_html__( 'Position Color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'condition' => [
					'team_position!' => ''
				]
			]
		);

		$repeater->add_control(
			'team_text',
			[
				'label'     => esc_html__( 'Text', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$repeater->add_control(
			'team_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'condition' => [
					'team_text!' => ''
				]
			]
		);

		$repeater->add_control(
			'team_link',
			[
				'label'     => esc_html__( 'Link', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$repeater->add_control(
			'team_target',
			[
				'label'     => esc_html__( 'Target', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'_self' => esc_html__( 'Same Window', 'solene-core'), 
					'_blank' => esc_html__( 'New Window', 'solene-core')
				),
				'default' => '_self',
				'condition' => [
					'team_link!' => ''
				]
			]
		);

		$repeater->add_control(
			'textual_social_icons',
			[
				'label'     => esc_html__( 'Display Text Instead Of Icon', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$repeater->add_control(
			'textual_social_1',
			[
				'label'     => esc_html__( 'Social 1', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'textual_social_icons' => array( 'yes' )
				]
			]
		);

		$repeater->add_control(
			'textual_social_link_1',
			[
				'label'     => esc_html__( 'Social 1 Link', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'textual_social_1!' => ''
				]
			]
		);

		$repeater->add_control(
			'textual_social_link_target_1',
			[
				'label'     => esc_html__( 'Social 1 Target', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'_self' => esc_html__( 'Same Window', 'solene-core'), 
					'_blank' => esc_html__( 'New Window', 'solene-core')
				),
				'default' => '_self',
				'condition' => [
					'textual_social_link_1!' => ''
				]
			]
		);

		$repeater->add_control(
			'textual_social_2',
			[
				'label'     => esc_html__( 'Social 2', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'textual_social_icons' => array( 'yes' )
				]
			]
		);

		$repeater->add_control(
			'textual_social_link_2',
			[
				'label'     => esc_html__( 'Social 2 Link', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'textual_social_2!' => ''
				]
			]
		);

		$repeater->add_control(
			'textual_social_link_target_2',
			[
				'label'     => esc_html__( 'Social 2 Target', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'_self' => esc_html__( 'Same Window', 'solene-core'), 
					'_blank' => esc_html__( 'New Window', 'solene-core')
				),
				'default' => '_self',
				'condition' => [
					'textual_social_link_2!' => ''
				]
			]
		);

		$repeater->add_control(
			'textual_social_3',
			[
				'label'     => esc_html__( 'Social 3', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'textual_social_icons' => array( 'yes' )
				]
			]
		);

		$repeater->add_control(
			'textual_social_link_3',
			[
				'label'     => esc_html__( 'Social 3 Link', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'textual_social_3!' => ''
				]
			]
		);

		$repeater->add_control(
			'textual_social_link_target_3',
			[
				'label'     => esc_html__( 'Social 3 Target', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'_self' => esc_html__( 'Same Window', 'solene-core'), 
					'_blank' => esc_html__( 'New Window', 'solene-core')
				),
				'default' => '_self',
				'condition' => [
					'textual_social_link_3!' => ''
				]
			]
		);

		$repeater->add_control(
			'textual_social_4',
			[
				'label'     => esc_html__( 'Social 4', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'textual_social_icons' => array( 'yes' )
				]
			]
		);

		$repeater->add_control(
			'textual_social_link_4',
			[
				'label'     => esc_html__( 'Social 4 Link', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'textual_social_4!' => ''
				]
			]
		);

		$repeater->add_control(
			'textual_social_link_target_4',
			[
				'label'     => esc_html__( 'Social 4 Target', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'_self' => esc_html__( 'Same Window', 'solene-core'), 
					'_blank' => esc_html__( 'New Window', 'solene-core')
				),
				'default' => '_self',
				'condition' => [
					'textual_social_link_4!' => ''
				]
			]
		);

		$repeater->add_control(
			'textual_social_5',
			[
				'label'     => esc_html__( 'Social 5', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'textual_social_icons' => array( 'yes' )
				]
			]
		);

		$repeater->add_control(
			'textual_social_link_5',
			[
				'label'     => esc_html__( 'Social 5 Link', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'textual_social_5!' => ''
				]
			]
		);

		$repeater->add_control(
			'textual_social_link_target_5',
			[
				'label'     => esc_html__( 'Social 5 Target', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'_self' => esc_html__( 'Same Window', 'solene-core'), 
					'_blank' => esc_html__( 'New Window', 'solene-core')
				),
				'default' => '_self',
				'condition' => [
					'textual_social_link_5!' => ''
				]
			]
		);

        $repeater->add_control(
            'team_social_icon_pack',
            [
                'type'        => \Elementor\Controls_Manager::SELECT,
                'label'         => esc_html__( 'Social Icon Pack', 'solene-core' ),
                'options'       => array_flip(array_merge( array( '' => '' ), solene_elated_icon_collections()->getIconCollectionsVCExclude( array('linea_icons', 'linear_icons') ) )),
                'condition' => [
                    'textual_social_icons' => 'no'
                ]
            ]
        );

        for ( $x = 1; $x < 6; $x ++ ) {
            $teamIconCollections = solene_elated_icon_collections()->getCollectionsWithSocialIcons();
            foreach ( $teamIconCollections as $collection_key => $collection ) {

                $repeater->add_control(
                    'team_social_' . $collection->param . '_' . $x,
                    [
                        'type'       => \Elementor\Controls_Manager::SELECT,
                        'label'    => esc_html__( 'Social Icon ', 'solene-core' ) . $x,
                        'options'  => array_flip($collection->getSocialIconsArrayVC()),
                        'condition' => [
                            'team_social_icon_pack' => array( $collection_key )
                        ]
                    ]
                );
            }
            $repeater->add_control(
                'team_social_icon_' . $x . '_link',
                [
                    'type'       => \Elementor\Controls_Manager::TEXT,
                    'label'      => esc_html__( 'Social Icon ', 'solene-core' ) . $x . esc_html__( ' Link', 'solene-core' ),
                    'condition' => [
                        'team_social_icon_pack' => solene_elated_icon_collections()->getIconCollectionsKeys()
                    ]
                ]
            );

            $repeater->add_control(
                'team_social_icon_' . $x . '_target',
                [
                    'type'       => \Elementor\Controls_Manager::SELECT,
                    'label'    => esc_html__( 'Social Icon ', 'solene-core' ) . $x . esc_html__( ' Target', 'solene-core' ),
                    'options'      => array(
                        '_self' => esc_html__( 'Same Window', 'solene-core' ),
                        '_blank' => esc_html__( 'New Window', 'solene-core' )
                    ),
                    'condition' => [
                        'team_social_icon_' . $x . '_link!' => ''
                    ]
                ]
            );

        }

		$this->add_control(
			'team_item',
			[
				'label'     => esc_html__( 'Team', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::REPEATER,
				'fields'     => $repeater->get_controls(),
				'title_field'     => esc_html__( 'Item', 'solene-core' )
			]
		);


		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();

		$holder_classes = $this->getHolderClasses( $params );
		$slider_data    = $this->getSliderData( $params );;
         ?>
		
		  <div class="eltdf-team-carousel-holder <?php echo esc_attr( $holder_classes ); ?>">
            <div class="eltdf-tc-inner eltdf-owl-slider" <?php echo solene_elated_get_inline_attrs( $slider_data ) ?>>
              		<?php foreach ( $params['team_item'] as $team ) {

                    if ( ! empty( $team['team_image'] ) ) {
                        $team['team_image'] = $team['team_image']['id'];
                    }

                    if ( ! empty( $team['team_hover_image'] ) ) {
                        $team['team_hover_image'] = $team['team_hover_image']['id'];
                    }

                    $team['holder_classes']       = $this->getItemHolderClasses( $team );
                    $team['team_name_tag']        = ! empty( $params['team_name_tag'] ) ? $params['team_name_tag'] : 'h3';
                    $team['team_social_icons']    = $this->getItemTeamSocialIcons( $team );
                    $team['team_textual']         = $this->getItemTeamTextual( $team );
                    $team['team_offset']          = $this->getItemTeamOffset( $team );
                    $team['team_name_styles']     = $this->getItemTeamNameStyles( $team );
                    $team['team_position_styles'] = $this->getItemTeamPositionStyles( $team );
                    $team['team_text_styles']     = $this->getItemTeamTextStyles( $team );

                    echo solene_core_get_shortcode_module_template_part( 'templates/'. $team['type'], 'team', '', $team );
                } ?>
			</div>
		</div>
<?php
	}

	private function getHolderClasses( $params ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['space_between_items'] ) ? 'eltdf-' . $params['space_between_items'] . '-space' : '';
		
		return implode( ' ', $holderClasses );
	}

	private function getSliderData( $params ) {
		$slider_data = array();
		
		$slider_data['data-number-of-items']        = $params['number_of_visible_items'] !== '' ? $params['number_of_visible_items'] : '3';
		$slider_data['data-enable-loop']            = ! empty( $params['slider_loop'] ) ? $params['slider_loop'] : '';
		$slider_data['data-enable-autoplay']        = ! empty( $params['slider_autoplay'] ) ? $params['slider_autoplay'] : '';
		$slider_data['data-slider-speed']           = ! empty( $params['slider_speed'] ) ? $params['slider_speed'] : '5000';
		$slider_data['data-slider-speed-animation'] = ! empty( $params['slider_speed_animation'] ) ? $params['slider_speed_animation'] : '600';
		$slider_data['data-enable-navigation']      = ! empty( $params['slider_navigation'] ) ? $params['slider_navigation'] : '';
		$slider_data['data-enable-pagination']      = ! empty( $params['slider_pagination'] ) ? $params['slider_pagination'] : '';
		
		return $slider_data;
	}

    private function getItemHolderClasses( $params ) {
        $holderClasses = array();

        $holderClasses[] = ! empty( $params['type'] ) ? 'eltdf-team-' . $params['type'] : '';

        return implode( ' ', $holderClasses );
    }

    private function getItemTeamSocialIcons( $params ) {
        extract( $params );
        $social_icons = array();

        if ( $team_social_icon_pack !== '' ) {

            $icon_pack                    = solene_elated_icon_collections()->getIconCollection( $team_social_icon_pack );
            $team_social_icon_type_label  = 'team_social_' . $icon_pack->param;
            $team_social_icon_param_label = $icon_pack->param;

            for ( $i = 1; $i <= $params['number_of_social_icons']; $i ++ ) {

                $team_social_icon   = ${$team_social_icon_type_label . '_' . $i};
                $team_social_link   = ${'team_social_icon_' . $i . '_link'};
                $team_social_target = ${'team_social_icon_' . $i . '_target'};

                if ( $team_social_icon !== '' ) {

                    $team_icon_params                                  = array();
                    $team_icon_params['icon_pack']                     = $team_social_icon_pack;
                    $team_icon_params[ $team_social_icon_param_label ] = $team_social_icon;
                    $team_icon_params['link']                          = ( $team_social_link !== '' ) ? $team_social_link : '';
                    $team_icon_params['target']                        = ( $team_social_target !== '' ) ? $team_social_target : '';

                    $social_icons[] = solene_elated_execute_shortcode( 'eltdf_icon', $team_icon_params );
                }
            }
        }

        return $social_icons;
    }

    private function getItemTeamTextual( $params ) {
        $team_textual = array();

        if ( $params['textual_social_icons'] != 'no') {
            for ($i = 1; $i <= 5; $i++) {

                $team_textual_text = $params['textual_social_' . $i];
                $team_textual_link = $params['textual_social_link_' . $i];
                $team_textual_target = $params['textual_social_link_target_' . $i];

                if ($team_textual_text !== '') {

                    $team_textual[$i-1]['text'] = ($team_textual_text !== '') ? $team_textual_text : '';
                    $team_textual[$i-1]['link'] = ($team_textual_link !== '') ? $team_textual_link : '';
                    $team_textual[$i-1]['target'] = ($team_textual_target !== '') ? $team_textual_target : '';

                }
            }
        }

        return $team_textual;
    }

    private function getItemTeamOffset( $params ) {
        $styles = array();

        if ( ! empty( $params['top_offset'] ) ) {
            $styles[] = 'margin-top: ' . solene_elated_filter_px( $params['top_offset'] ) . 'px';
        }

        return implode( ';', $styles );
    }

    private function getItemTeamNameStyles( $params ) {
        $styles = array();

        if ( ! empty( $params['team_name_color'] ) ) {
            $styles[] = 'color: ' . $params['team_name_color'];
        }

        return implode( ';', $styles );
    }

    private function getItemTeamPositionStyles( $params ) {
        $styles = array();

        if ( ! empty( $params['team_position_color'] ) ) {
            $styles[] = 'color: ' . $params['team_position_color'];
        }

        return implode( ';', $styles );
    }

    private function getItemTeamTextStyles( $params ) {
        $styles = array();

        if ( ! empty( $params['team_text_color'] ) ) {
            $styles[] = 'color: ' . $params['team_text_color'];
        }

        return implode( ';', $styles );
    }

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorTeamCarousel() );