<?php
class SoleneCoreElementorTeam extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_team'; 
	}

	public function get_title() {
		return esc_html__( 'Team', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-team';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'type',
			[
				'label'     => esc_html__( 'Type', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'info-below-image' => esc_html__( 'Info Below Image', 'solene-core'), 
					'info-on-image' => esc_html__( 'Info On Image Hover', 'solene-core')
				),
				'default' => 'info-below-image'
			]
		);

		$this->add_control(
			'top_offset',
			[
				'label'     => esc_html__( 'Top Offset (px)', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'condition' => [
					'type' => array( 'info-below-image' )
				]
			]
		);

		$this->add_control(
			'team_image',
			[
				'label'     => esc_html__( 'Image', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA
			]
		);

		$this->add_control(
			'team_hover_image',
			[
				'label'     => esc_html__( 'Hover Image', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'type' => array( 'info-below-image' )
				]
			]
		);

		$this->add_control(
			'team_name',
			[
				'label'     => esc_html__( 'Name', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'team_name_tag',
			[
				'label'     => esc_html__( 'Name Tag', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'' => esc_html__( 'Default', 'solene-core'), 
					'h1' => esc_html__( 'h1', 'solene-core'), 
					'h2' => esc_html__( 'h2', 'solene-core'), 
					'h3' => esc_html__( 'h3', 'solene-core'), 
					'h4' => esc_html__( 'h4', 'solene-core'), 
					'h5' => esc_html__( 'h5', 'solene-core'), 
					'h6' => esc_html__( 'h6', 'solene-core')
				),
				'default' => 'h3',
				'condition' => [
					'team_name!' => ''
				]
			]
		);

		$this->add_control(
			'team_name_color',
			[
				'label'     => esc_html__( 'Name Color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'condition' => [
					'team_name!' => ''
				]
			]
		);

		$this->add_control(
			'team_position',
			[
				'label'     => esc_html__( 'Position', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'team_position_color',
			[
				'label'     => esc_html__( 'Position Color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'condition' => [
					'team_position!' => ''
				]
			]
		);

		$this->add_control(
			'team_text',
			[
				'label'     => esc_html__( 'Text', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'team_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'condition' => [
					'team_text!' => ''
				]
			]
		);

		$this->add_control(
			'team_link',
			[
				'label'     => esc_html__( 'Link', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT
			]
		);

		$this->add_control(
			'team_target',
			[
				'label'     => esc_html__( 'Target', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'_self' => esc_html__( 'Same Window', 'solene-core'), 
					'_blank' => esc_html__( 'New Window', 'solene-core')
				),
				'default' => '_self',
				'condition' => [
					'team_link!' => ''
				]
			]
		);

		$this->add_control(
			'textual_social_icons',
			[
				'label'     => esc_html__( 'Display Text Instead Of Icon', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'textual_social',
            [
                'label' => esc_html__( 'Social Text', 'solene-core' ),
                'type'  => \Elementor\Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control(
            'textual_social_link',
            [
                'label' => esc_html__( 'Social Text Link', 'solene-core' ),
                'type'  => \Elementor\Controls_Manager::TEXT,
                'condition' => [
                    'textual_social!' => ''
                ]
            ]
        );

        $repeater->add_control(
            'textual_social_link_target',
            [
                'label'   => esc_html__( 'Social Target', 'solene-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => solene_elated_get_link_target_array(),
                'default' => '_self',
                'condition' => [
                    'textual_social_link!' => ''
                ]
            ]
        );

        $this->add_control(
            'social_textual_item',
            [
                'label'       => esc_html__( 'Textual Social', 'solene-core' ),
                'type'        => \Elementor\Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => esc_html__( 'Item' ),
                'condition' => [
                    'textual_social_icons' => 'yes'
                ]
            ]
        );

        $repeater2 = new \Elementor\Repeater();

        solene_elated_icon_collections()->getElementorParamsArray( $repeater, '', '' );

        $repeater2->add_control(
            'team_social_icon_link',
            [
                'label' => esc_html__( 'Social Icon Link', 'solene-core' ),
                'type'  => \Elementor\Controls_Manager::TEXT,
            ]
        );

        $repeater2->add_control(
            'team_social_icon_target',
            [
                'label'   => esc_html__( 'Social Icon Target', 'solene-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => solene_elated_get_link_target_array(),
                'default' => '_self'
            ]
        );

        $this->add_control(
            'social_icon_item',
            [
                'label'       => esc_html__( 'Social Icons', 'solene-core' ),
                'type'        => \Elementor\Controls_Manager::REPEATER,
                'fields'      => $repeater2->get_controls(),
                'title_field' => esc_html__( 'Social Icon' ),
                'condition' => [
                    'textual_social_icons' => 'no'
                ]
            ]
        );



		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();

        $params['team_image']           = ! empty($params['team_image']) ? $params['team_image']['id'] : $params['team_image'];
        $params['team_hover_image']     = ! empty($params['team_hover_image']) ? $params['team_hover_image']['id'] : $params['team_hover_image'];
        $params['type']                 = ! empty( $params['type'] ) ? $params['type'] : '';
		$params['holder_classes']       = $this->getHolderClasses( $params );
		$params['team_name_tag']        = ! empty( $params['team_name_tag'] ) ? $params['team_name_tag'] : 'h3';
		$params['team_social_icons']    = $this->getTeamSocialIcons( $params );
		$params['team_textual']         = $this->getTeamTextual( $params );
		$params['team_offset']          = $this->getTeamOffset( $params );
		$params['team_name_styles']     = $this->getTeamNameStyles( $params );
		$params['team_position_styles'] = $this->getTeamPositionStyles( $params );
		$params['team_text_styles']     = $this->getTeamTextStyles( $params );
		
		//Get HTML from template based on type of team
        echo solene_core_get_shortcode_module_template_part( 'templates/' . $params['type'], 'team', '', $params );

	}

	private function getHolderClasses( $params ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['type'] ) ? 'eltdf-team-' . $params['type'] : '';
		
		return implode( ' ', $holderClasses );
	}

	private function getTeamSocialIcons( $params ) {
        $team_social_icons = array();

        if ( $params['textual_social_icons'] == 'no' && !empty($params['social_icon_item'])) {

            foreach ( $params['social_icon_item'] as $icon ) {

                $iconPackName = solene_elated_icon_collections()->getIconCollectionParamNameByKey( $icon['icon_pack'] );

                $team_icon_params                  = array();
                $team_icon_params['icon_pack']     = $icon['icon_pack'];
                $team_icon_params[ $iconPackName ] = $icon[ $iconPackName ];
                $team_icon_params['link']          = $icon['team_social_icon_link'];
                $team_icon_params['target']        = $icon['team_social_icon_target'];

                $team_social_icons[] = solene_elated_execute_shortcode( 'eltdf_icon', $team_icon_params );
            }
        }

        return $team_social_icons;
	}

    private function getTeamTextual( $params ) {
        $team_textual = array();

        if ( $params['textual_social_icons'] == 'yes' && !empty($params['social_textual_item'])) {
			$i = 0;
            foreach ( $params['social_textual_item'] as $item ) {
                $team_textual[$i]['text']       = $item['textual_social'];
                $team_textual[$i]['link']       = $item['textual_social_link'];
                $team_textual[$i]['target']     = $item['textual_social_link_target'];

                $i++;
            }
        }

        return $team_textual;
    }

	private function getTeamOffset( $params ) {
		$styles = array();
		
		if ( ! empty( $params['top_offset'] ) ) {
			$styles[] = 'margin-top: ' . solene_elated_filter_px( $params['top_offset'] ) . 'px';
		}
		
		return implode( ';', $styles );
	}

	private function getTeamNameStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['team_name_color'] ) ) {
			$styles[] = 'color: ' . $params['team_name_color'];
		}
		
		return implode( ';', $styles );
	}

	private function getTeamPositionStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['team_position_color'] ) ) {
			$styles[] = 'color: ' . $params['team_position_color'];
		}
		
		return implode( ';', $styles );
	}

	private function getTeamTextStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['team_text_color'] ) ) {
			$styles[] = 'color: ' . $params['team_text_color'];
		}
		
		return implode( ';', $styles );
	}

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorTeam() );