<?php
class SoleneCoreElementorWorkflow extends \Elementor\Widget_Base {

	public function get_name() {
		return 'eltdf_workflow'; 
	}

	public function get_title() {
		return esc_html__( 'Workflow', 'solene-core' );
	}

	public function get_icon() {
		return 'solene-elementor-custom-icon solene-elementor-workflow';
	}

	public function get_categories() {
		return [ 'elated' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'solene-core' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'custom_clas',
			[
				'label'     => esc_html__( 'Extra class name', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'solene-core' )
			]
		);

		$this->add_control(
			'line_color',
			[
				'label'     => esc_html__( 'Workflow line color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'description' => esc_html__( 'Pick a color for the workflow line.', 'solene-core' )
			]
		);

		$this->add_control(
			'animate',
			[
				'label'     => esc_html__( 'Animate Workflow', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'description' => esc_html__( 'Animate Workflow shortcode when it comes into viewport', 'solene-core' ),
				'options' => array(
					'yes' => esc_html__( 'Yes', 'solene-core'), 
					'no' => esc_html__( 'No', 'solene-core')
				),
				'default' => 'yes'
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'title',
			[
				'label'     => esc_html__( 'Title', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( 'Enter workflow item title.', 'solene-core' )
			]
		);

		$repeater->add_control(
			'text',
			[
				'label'     => esc_html__( 'Text', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'Enter workflow item text.', 'solene-core' )
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'     => esc_html__( 'Image', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::MEDIA,
				'description' => esc_html__( 'Insert workflow item image.', 'solene-core' )
			]
		);

		$repeater->add_control(
			'circle_border_color',
			[
				'label'     => esc_html__( 'Circle border color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'description' => esc_html__( 'Pick a color for the circle border color.', 'solene-core' )
			]
		);

		$repeater->add_control(
			'circle_background_color',
			[
				'label'     => esc_html__( 'Circle background color', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'description' => esc_html__( 'Pick a color for the circle background color.', 'solene-core' )
			]
		);

		$this->add_control(
			'workflow_item',
			[
				'label'     => esc_html__( 'Workflow Item', 'solene-core' ),
				'type'      => \Elementor\Controls_Manager::REPEATER,
				'fields'     => $repeater->get_controls(),
				'title_field'     => esc_html__( 'Item', 'solene-core' )
			]
		);


		$this->end_controls_section();
	}
	public function render() {

		$params = $this->get_settings_for_display();


        $style_params = $this->getStyleProperties($params);
        $params       = array_merge($params, $style_params);
        extract($params);

        $params['custom_clas'] = $this->getWorkflowClasses($params);
        $params['content']  = $content;
        $output             = '';

        ?>

        <div class="eltdf-workflow <?php echo esc_attr($params['custom_class']) ?>">
            <span class="main-line" style="<?php echo esc_attr($params['main_line_style']); ?>"></span>
            <?php foreach ($params['workflow_item'] as $wi) {
                $wi['holder_classes']          = $this->getItemStyleProperties( $wi );
                if(!empty($wi['image'])){
                    $wi['image'] = $wi['image']['id'];
                }

                echo solene_core_get_shortcode_module_template_part('templates/workflow-item-template', 'workflow', '', $wi);

            } ?>
        </div>
        <?php }

    private function getWorkflowClasses($params) {

        $custom_clas = '';
        $class    = $params['custom_clas'];

        if($class !== '') {
            $custom_clas = $class;
        }

        if($params['animate'] == 'yes') {
            $custom_clas = 'eltdf-workflow-animate';
        }

        return $custom_clas;
    }

    private function getStyleProperties($params) {

        $style                    = array();
        $style['main_line_style'] = '';

        if($params['line_color'] !== '') {
            $style['main_line_style'] = 'background-color:'.$params['line_color'].';';
        }

        return $style;
    }

    private function getItemStyleProperties($params) {

        $style                            = array();
        $style['circle_border_color']     = '';
        $style['circle_background_color'] = '';
        $style['line_color']              = '';

        if($params['circle_border_color'] !== '') {
            $style['circle_border_color'] = 'border-color:'.$params['circle_border_color'].';';
        }
        if($params['circle_background_color'] !== '') {
            $style['circle_background_color'] = 'background-color:'.$params['circle_background_color'].';';
        }

        return $style;
    }

}
\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneCoreElementorWorkflow() );