<?php

class SoleneTwitterFeedElementorTwitterList extends \Elementor\Widget_Base {

    public function get_name() {
        return 'eltdf_twitter_list';
    }

    public function get_title() {
        return esc_html__( 'Twitter List', 'solene-twitter-feed' );
    }

    public function get_icon() {
        return 'solene-elementor-custom-icon solene-elementor-twitter-list';
    }

    public function get_categories() {
        return [ 'elated' ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'general',
            [
                'label' => esc_html__( 'General', 'solene-twitter-feed' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

		$this->add_control(
			'user_id',
			[
				'label'       => esc_html__( 'User ID', 'solene-twitter-feed' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
			]
		);

        $this->add_control(
            'number_of_columns',
            [
                'label'       => esc_html__( 'Number of Columns', 'solene-twitter-feed' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
				'options'     => solene_elated_get_number_of_columns_array( false, array( 'one' ) ),
                'default'     => 'four'
            ]
        );

        $this->add_control(
            'space_between_columns',
            [
                'label'   => esc_html__( 'Space Between Items', 'solene-twitter-feed' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
				'options' => solene_elated_get_space_between_items_array(),
                'default' => 'normal'
            ]
        );

        $this->add_control(
            'number_of_tweets',
            [
                'label'       => esc_html__( 'Number of Tweets', 'solene-twitter-feed' ),
                'type'        => \Elementor\Controls_Manager::TEXT,
            ]
        );

		$this->add_control(
			'transient_time',
			[
				'label'       => esc_html__( 'Tweets Cache Time', 'solene-twitter-feed' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => ''
			]
		);

        $this->end_controls_section();
    }

    public function render() {

		$args   = array(
			'user_id'               => '',
			'number_of_columns'     => 'four',
			'space_between_columns' => 'normal',
			'number_of_tweets'      => '',
			'transient_time'        => ''
		);
		$params = shortcode_atts( $args, $this->get_settings_for_display() );
		extract( $params );

		$params['holder_classes'] = $this->getHolderClasses( $params, $args );

		$twitter_api           = new \SoleneTwitterApi();
		$params['twitter_api'] = $twitter_api;

		if ( $twitter_api->hasUserConnected() ) {
			$response = $twitter_api->fetchTweets( $user_id, $number_of_tweets, array(
				'transient_time' => $transient_time,
				'transient_id'   => 'eltdf_twitter_' . rand( 0, 1000 )
			) );

			$params['response'] = $response;
		}

		//Get HTML from template based on type of team
		echo solene_twitter_get_shortcode_module_template_part( 'holder', 'twitter-list', '', $params );

	}

	public function getHolderClasses( $params, $args ) {
		$holderClasses = array();

		$holderClasses[] = ! empty( $params['number_of_columns'] ) ? 'eltdf-' . $params['number_of_columns'] . '-columns' : 'eltdf-' . $args['number_of_columns'] . '-columns';
		$holderClasses[] = ! empty( $params['space_between_columns'] ) ? 'eltdf-' . $params['space_between_columns'] . '-space' : 'eltdf-' . $args['space_between_columns'] . '-space';

		return implode( ' ', $holderClasses );
	}

}

\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new SoleneTwitterFeedElementorTwitterList() );